﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Xml;
using System.IO;
using Server;

namespace GoogleMapAPIUphold
{
    public partial class Form1 : Form
    {
        private static Form1 myForm=null;
        private  Form1()
        {
           InitializeComponent();
        }

        public static Form1 Instance()
        { 
             
             if (myForm == null)
             {
                 myForm = new Form1();
             }

             
             return myForm;
        }

        private TreeNode _CurrentNode;

        #region 窗体事件
        /// <summary>
        /// 窗体加载
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        public void Form1_Load(object sender, EventArgs e)
        {
            CreateTreeView();
        }

        #endregion

        #region 控件事件

        /// <summary>
        /// 激发树节点选择后事件
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void treeGA_AfterSelect(object sender, TreeViewEventArgs e)
        {
            //获取节点
            _CurrentNode = e.Node;
            //获取属性
            TreeAttribute attribute = (TreeAttribute)e.Node.Tag;

            if (attribute.SouceURL == "none")
                return;
            else
            {

                //页面源码
                this.richGA.Text=IOAccess.GetWordText( Application.StartupPath + @"\Source\" + attribute.SouceURL);
            }

            if (attribute.GAURL == "none")
                return;
            else
                this.richGA.Text = IOAccess.GetWordText(Application.StartupPath + @"\GA\" + attribute.GAURL);

        }
        #endregion

        #region 菜单方法
        /// <summary>
        /// 维护—>添加
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void itemAdd_Click(object sender, EventArgs e)
        {
            if (_CurrentNode == null)
            {
                MessageBox.Show("请选择父节点", "维护->添加", MessageBoxButtons.OK, MessageBoxIcon.Information);
                return;
            }

            TreeAttribute attribute = (TreeAttribute)_CurrentNode.Tag;
            if (attribute.Deep != 2)
            {
                MessageBox.Show("当前只支持Deep=2的节点做为父节点", "提示", MessageBoxButtons.OK, MessageBoxIcon.Information);
                return;
            }

            GAEditDetail item = new GAEditDetail(_CurrentNode,this.Location,DetailStatus.New);
            item.ShowDialog();
        }
        /// <summary>
        /// 维护—>编辑
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void itemEdit_Click(object sender, EventArgs e)
        {
            if (_CurrentNode == null)
            {
                MessageBox.Show("请选择节点", "维护->维护", MessageBoxButtons.OK, MessageBoxIcon.Information);
                return;
            }

            TreeAttribute attribute = (TreeAttribute)_CurrentNode.Tag;
            if (attribute.Deep != 3)
            {
                MessageBox.Show("当前只支持Deep=3的节点编辑", "提示", MessageBoxButtons.OK, MessageBoxIcon.Information);
                return;
            }

            GAEditDetail item = new GAEditDetail(_CurrentNode, this.Location, DetailStatus.Edit);
            item.ShowDialog();
        }
        /// <summary>
        /// 维护—>删除
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void itemDel_Click(object sender, EventArgs e)
        {

            if (_CurrentNode == null)
            {
                MessageBox.Show("请选择节点", "维护->维护", MessageBoxButtons.OK, MessageBoxIcon.Information);
                return;
            }

            TreeAttribute attribute = (TreeAttribute)_CurrentNode.Tag;
            if (attribute.Deep != 3)
            {
                MessageBox.Show("当前只支持Deep=3的节点编辑", "提示", MessageBoxButtons.OK, MessageBoxIcon.Information);
                return;
            }

            if (MessageBox.Show("将删除" + attribute.Text + "节点,你确定吗？", "删除节点", MessageBoxButtons.OKCancel, MessageBoxIcon.Warning) == DialogResult.OK)
            {
                XMLAccess.DelNodeToTree(attribute);
                IOAccess.DelFile(Application.StartupPath + @"\Source\" + attribute.SouceURL);
                IOAccess.DelFile(Application.StartupPath + @"\GA\" + attribute.GAURL);
            }

            CreateTreeView();
            this.webBrowser.Url = null;
            this.richSource.Clear();
            this.richGA.Clear();
            this._CurrentNode = null;
        }

        /// <summary>
        /// 清空备份文件
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void itemClearBackup_Click(object sender, EventArgs e)
        {
            try
            {
                if (Directory.Exists(Application.StartupPath + @"\Source\Backup") && Directory.Exists(Application.StartupPath + @"\GA\Backup"))
                {
                    Directory.Delete(Application.StartupPath + @"\Source\Backup", true);
                    Directory.CreateDirectory(Application.StartupPath + @"\Source\Backup");
                    Directory.Delete(Application.StartupPath + @"\GA\Backup", true);
                    Directory.CreateDirectory(Application.StartupPath + @"\GA\Backup");
                }
            }
            catch(Exception err)
            {
                MessageBox.Show("文件正在被使用，不能删除备份文件\n"+err.ToString());
                return;
            }

            MessageBox.Show("备份文件清理成功");
        }

        /// <summary>
        /// 不绑定代码节点
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void itemNoneBind_Click(object sender, EventArgs e)
        {
            //功能尚未开启
        }

       

        #endregion

        #region 方法

        /// <summary>
        /// 创建树视图
        /// </summary>
        public void CreateTreeView()
        {
            this.treeGA.Nodes.Clear();

            XmlNode xn = XMLAccess.GetXmlRoot("Tree.xml");
            //处理节点
            if (xn.NodeType == XmlNodeType.Element)
            {
                TreeAttribute attribute = new TreeAttribute();

                attribute.Name = xn.Name;
                attribute.Text = xn.Attributes["Text"].Value;
                attribute.Deep = Int32.Parse(xn.Attributes["Deep"].Value);
                attribute.Parent = xn.Attributes["Parent"].Value;
                attribute.SouceURL = xn.Attributes["SourceURL"].Value;
                attribute.GAURL = xn.Attributes["GAURL"].Value;
                attribute.Extention = xn.Attributes["Extention"].Value;

                if (attribute.Deep < 1 && attribute.Deep > 3)
                    return;
                if (attribute.Deep == 1)
                {
                    TreeNode Root = new TreeNode();

                    Root.Text = attribute.Text;
                    Root.Tag = attribute as object;
                    Root.ForeColor = Color.Red;

                    treeGA.Nodes.Add(Root);
                    GetTreeViewChild(attribute.Name, Root, attribute.Deep);  //获取孩子节点
                }
            }

        }

        //获取孩子节点
        public void GetTreeViewChild(string parent, TreeNode Root, int Deep)
        {
            DataSet ds = XMLAccess.GetXmlDataSet("Tree.xml");

            for(int i=0;i<ds.Tables.Count;i++)
            {
                TreeAttribute attribute = new TreeAttribute();

                attribute.Name = ds.Tables[i].TableName;
                attribute.Text = ds.Tables[i].Rows[0]["Text"].ToString();
                attribute.Deep = Int32.Parse(ds.Tables[i].Rows[0]["Deep"].ToString());
                attribute.Parent = ds.Tables[i].Rows[0]["Parent"].ToString();
                attribute.SouceURL = ds.Tables[i].Rows[0]["SourceURL"].ToString();
                attribute.GAURL = ds.Tables[i].Rows[0]["GAURL"].ToString();
                attribute.Extention = ds.Tables[i].Rows[0]["Extention"].ToString();

                if (attribute.Deep < 1 && attribute.Deep > 3)
                    break;
               
                if ((attribute.Parent == parent && (attribute.Deep - Deep == 1)))
                {
                    TreeNode Node = new TreeNode();

                    Node.Text = attribute.Text;
                    Node.Tag = attribute as object;
                    if(attribute.Deep==2)
                        Node.ForeColor = Color.Red;
                    if (attribute.Deep >= 3)
                        Node.ForeColor = Color.Blue;

                    Root.Nodes.Add(Node);

                    Root.Expand();
                    GetTreeViewChild(attribute.Name, Node, attribute.Deep);
                }

            }
        }

        #endregion

        /// <summary>
        /// 页面源码搜索
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void btnSourceSearch_Click(object sender, EventArgs e)
        {
            //this.richSource.s
        }

        private void 退出ToolStripMenuItem_Click(object sender, EventArgs e)
        {
            this.Close();
        }

        

       

    }
}