﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.IO;
using Server;

namespace GoogleMapAPIUphold
{
    public partial class GAEditDetail : Form
    {
        public GAEditDetail()
        {
            InitializeComponent();
        }

        public GAEditDetail(TreeNode item,Point pointLocation,DetailStatus status)
        {
            _CurrentNode = item;
            this.Location = pointLocation;
            _CurrentStatus = status;

            InitializeComponent();
        }

        #region 变量及属性

        //获取节点
        private TreeNode _CurrentNode;

        public TreeNode CurrentNode
        {
            get { return _CurrentNode; }
            set { _CurrentNode = value; }
        }

        //获取状态
        private DetailStatus _CurrentStatus;

        public DetailStatus CurrentStatus
        {
            get { return _CurrentStatus; }
            set { _CurrentStatus = value; }
        }

        private TreeAttribute _NewTreeAttribute;

        public TreeAttribute NewTreeAttribute
        {
            get { return _NewTreeAttribute; }
            set { _NewTreeAttribute = value; }
        }

        #endregion

        #region 窗体

        private void GAEditDetail_Load(object sender, EventArgs e)
        {
            //验证
            if (VerifyResult() != "OK" && _CurrentStatus==DetailStatus.New)
            {
               throw new Exception(VerifyResult());
            }

            //获取编辑或新建状态
            if (_CurrentStatus == DetailStatus.Edit)
            {
                this.txtNodeName.Enabled = false;
                this.txtFileName.Enabled = false;
                BindEditStatus();
            }

            else
                BindNewStatus();

        }

        #endregion


        #region 方法

        /// <summary>
        /// 对传入的父节点做验证，验证不通过则退出维护窗体
        /// </summary>
        /// <param name="parent"></param>
        /// <returns></returns>
        public eDateVerify DataVerify(TreeNode parent)
        {
            TreeAttribute attribute = (TreeAttribute)parent.Tag;
            //深度检查
            if (attribute.Deep != 2)
                return eDateVerify.DeepError;
            if(string.IsNullOrEmpty(attribute.GAURL))
                return eDateVerify.GAURLError;
            if(string.IsNullOrEmpty(attribute.SouceURL))
                return eDateVerify.SourceURLError;
            if(string.IsNullOrEmpty(attribute.Parent))
                return eDateVerify.ParentError;
            if(string.IsNullOrEmpty(attribute.Text))
                return eDateVerify.TextError;
            return eDateVerify.OK;
        }

        /// <summary>
        /// 验证结果
        /// </summary>
        /// <returns></returns>
        public string VerifyResult()
        {
            string result=string.Empty;
            switch (DataVerify(_CurrentNode))
            { 
                case eDateVerify.DeepError:
                    result = "DeepError";
                    break;
                case eDateVerify.GAURLError:
                    result = "GAURLError";
                    break;
                case eDateVerify.OK:
                    result = "OK";
                    break;
                case eDateVerify.ParentError:
                    result = "ParentError";
                    break;
                case eDateVerify.SourceURLError:
                    result = "SourceURLError";
                    break;
                case eDateVerify.TextError:
                    result = "TextError";
                    break;
            }

            return result;
        }

        /// <summary>
        /// 新建状态数据绑定
        /// </summary>
        public void BindNewStatus()
        {
            TreeAttribute attribute=(TreeAttribute)_CurrentNode.Tag;
            this.txtParentName.Text = attribute.Name;
            this.txtNodeDeep.Text = (attribute.Deep + 1).ToString();
        }

        /// <summary>
        /// 编辑状态数据绑定
        /// </summary>
        public void BindEditStatus()
        {
            TreeAttribute attribute = (TreeAttribute)_CurrentNode.Tag;
            this.txtParentName.Text = attribute.Parent;
            this.txtNodeDeep.Text = attribute.Deep.ToString();

            this.txtNodeName.Text = attribute.Name;
            this.txtNodeText.Text = attribute.Text;
            this.txtFileName.Text = attribute.GAURL.Substring(0, attribute.GAURL.Length - 4);
            this.txtExtention.Text=attribute.Extention;

            this.txtSource.Text = IOAccess.GetWordText(Application.StartupPath + @"\Source\" + attribute.SouceURL);
            this.txtGA.Text = IOAccess.GetWordText(Application.StartupPath + @"\GA\" + attribute.GAURL);
        }

        /// <summary>
        /// 新建数据
        /// </summary>
        /// <param name="attribute"></param>
        /// <returns></returns>
        public bool NewData(TreeAttribute attribute)
        {
            if (VerifySubmit() != "OK")
            {
                MessageBox.Show(VerifySubmit());
                return false;
            }

            //修改Tree.xml
            XMLAccess.WriteNodeToTree(attribute);
            //添加源文件
            IOAccess.CreatFile(Application.StartupPath + @"\Source\" + attribute.SouceURL, this.txtSource.Text);
            //添加GA分析
            IOAccess.CreatFile(Application.StartupPath + @"\GA\" + attribute.GAURL, this.txtGA.Text);
            return true;
        }

        /// <summary>
        /// 保存编辑数据
        /// </summary>
        /// <param name="attribute"></param>
        /// <returns></returns>
        public bool SaveData(TreeAttribute attribute)
        {
            if (VerifySubmit() != "OK")
            {
                MessageBox.Show(VerifySubmit());
                return false;
            }

            ////修改Tree.xml
            XMLAccess.EditNodeToTree(attribute);
            //添加源文件
            IOAccess.EditFile(Application.StartupPath + @"\Source\" + attribute.SouceURL, this.txtSource.Text, true,FolderState.Source);
            //添加GA分析
            IOAccess.EditFile(Application.StartupPath + @"\GA\" + attribute.GAURL, this.txtGA.Text, true,FolderState.GA);
            return true;


        }

        /// <summary>
        /// 提交前验证数据有效性
        /// </summary>
        /// <returns></returns>
        public string VerifySubmit()
        {
            if (string.IsNullOrEmpty(txtNodeName.Text.Trim()))
                return "节点名不能为空";
            if (string.IsNullOrEmpty(txtNodeText.Text.Trim()))
                return "节点文本不能为空";
            if (string.IsNullOrEmpty(txtFileName.Text.Trim()))
                return "文件名不能为空";
            if (string.IsNullOrEmpty(txtSource.Text.Trim()))
                return "源文件不能为空";
            if (string.IsNullOrEmpty(txtGA.Text.Trim()))
                return "GA分析不能为空";

            System.Text.RegularExpressions.Regex regex = new System.Text.RegularExpressions.Regex(@"^[a-zA-z]+$");
            if (!regex.IsMatch(this.txtNodeName.Text.Trim()))
                return "节点名必须为字母组成的字符串";



            return "OK";
        }

        /// <summary>
        /// 构造TreeAttribute
        /// </summary>
        public void StructNewTreeAttribute()
        {
            _NewTreeAttribute.Deep = Int32.Parse( this.txtNodeDeep.Text.Trim());
            _NewTreeAttribute.Extention = this.txtExtention.Text;
            _NewTreeAttribute.GAURL = this.txtFileName.Text.Trim() + ".txt";
            _NewTreeAttribute.SouceURL = this.txtFileName.Text.Trim() + ".html";
            _NewTreeAttribute.Name = this.txtNodeName.Text.Trim();
            _NewTreeAttribute.Parent = this.txtParentName.Text.Trim();
            _NewTreeAttribute.Text = this.txtNodeText.Text.Trim();
        }

        #endregion 

        #region 按钮
        private void btnOk_Click(object sender, EventArgs e)
        {
            bool result;
            //构造TreeAttribute
            StructNewTreeAttribute();
            //判断状态
            if (_CurrentStatus == DetailStatus.New)
                result=NewData(_NewTreeAttribute);
            else
                result=SaveData(_NewTreeAttribute);

            if (result)
            {
                MessageBox.Show("信息提交成功", "提示", MessageBoxButtons.OK, MessageBoxIcon.Information);
                //刷新Form1
                this.Close();
                Form1.Instance().Form1_Load(null, null);
            }
            
        }

        private void btnCanel_Click(object sender, EventArgs e)
        {
            this.Close();
        }

         #endregion 


    }
}