﻿using System;
using System.Collections.Generic;
using System.Text;
using System.IO;
using System.Windows.Forms;

namespace Server
{
    public static class IOAccess
    {
        /// <summary>
        /// 字节流读取文件
        /// </summary>
        /// <returns></returns>
        public static string GetWordText(string filepath)
        {
            if(!File.Exists(filepath))
            {
                return null;
            }
            FileInfo fi = new FileInfo(filepath);
            long len = fi.Length;
            FileStream fs = new FileStream(filepath, FileMode.Open);
            byte[] buffer = new byte[len];
            fs.Read(buffer, 0, (int)len);
            fs.Close();

            return System.Text.Encoding.Default.GetString(buffer);

        }

        /// <summary>
        /// 创建文件，为其他创建文件的方法服务
        /// </summary>
        /// <param name="filepath"></param>
        /// <param name="strContent"></param>
        public static void WriteFile(string filepath,string strContent)
        {
             long len = strContent.Length;
            FileStream fs = new FileStream(filepath, FileMode.CreateNew);
            byte[] buffer = System.Text.Encoding.Default.GetBytes(strContent);
            fs.Write(buffer, 0, (int)len);
            fs.Close();

        }

        /// <summary>
        /// 创建文件，并将内容写入
        /// </summary>
        /// <param name="filepath">文件路径</param>
        /// <param name="strContent">文件内容</param>
        /// <returns></returns>
        public static bool CreatFile(string filepath, string strContent)
        {
            if (File.Exists(filepath))
            {
                MessageBox.Show("已存在同名文件，为确保系统稳定运行，创建文件失败！请重新输入文件名");
                return false;
            }

            WriteFile(filepath, strContent);
           
            return true;
        }

        /// <summary>
        /// 编辑文件，操作不安全，不建议使用
        /// </summary>
        /// <param name="filepath">文件路径</param>
        /// <param name="strContent">文件内容</param>
        /// <returns></returns>
        public static bool EditFile(string filepath, string strContent)
        {
            if (File.Exists(filepath))
            {
                File.Delete(filepath);
            }

            WriteFile(filepath, strContent);

            return true ;
        }

        /// <summary>
        /// 编辑文件，提供备份功能
        /// </summary>
        /// <param name="filepath">文件路径</param>
        /// <param name="strContent">文件内容</param>
        /// <param name="CreateBackup">是否创建备份</param>
        /// <returns></returns>
        public static bool EditFile(string filepath, string strContent, bool CreateBackup)
        {
            string fileBack = filepath;
            filepath = filepath + ".bak." + ReturnDateTimeString();
            if (File.Exists(filepath))
            {
                if (CreateBackup)
                    WriteFile(filepath, strContent);
                File.Delete(fileBack);
            }
            WriteFile(fileBack, strContent);
            return true;
        }

        /// <summary>
        /// 编辑文件，提供备份功能
        /// </summary>
        /// <param name="filepath">文件路径</param>
        /// <param name="strContent">文件内容</param>
        /// <param name="CreateBackup">是否创建备份</param>
        /// /// <param name="status">传递文件类型</param>
        /// <returns></returns>
        public static bool EditFile(string filepath, string strContent, bool CreateBackup,FolderState status)
        {
            string fileBack = filepath;
            filepath=filepath + ".bak." + ReturnDateTimeString();
            if (File.Exists(filepath))
            {
                if (CreateBackup)
                    WriteFile(filepath, strContent);
                File.Delete(fileBack);
            }
            WriteFile(fileBack, strContent);

            MoveBakFileToFolder(filepath, status);
            return true;
        }

        /// <summary>
        /// 返回时间字符串
        /// </summary>
        /// <returns></returns>
        public static string ReturnDateTimeString()
        {
            return DateTime.Now.Year.ToString() +
                    DateTime.Now.Month.ToString() +
                    DateTime.Now.Day.ToString() +
                    DateTime.Now.Hour.ToString() +
                    DateTime.Now.Minute.ToString() +
                    DateTime.Now.Second.ToString();
        }

        /// <summary>
        /// 删除文件
        /// </summary>
        /// <param name="filepath"></param>
        /// <returns></returns>
        public static bool DelFile(string filepath)
        {

            if (File.Exists(filepath))
            {
                File.Delete(filepath);
                return true;
            }
            else
                return false;
        }

        /// <summary>
        /// 将备份文件夹放入单独文件
        /// </summary>
        /// <param name="filepath"></param>
        /// <param name="status"></param>
        /// <returns></returns>
        public static bool MoveBakFileToFolder(string filepath, FolderState status)
        {

            if (!File.Exists(filepath))
                return false;

            //移动的文件路径
            string fileTo = string.Empty;
            switch (status)
            { 
                case FolderState.Source:
                    fileTo=Application.StartupPath+@"\Source\Backup\"+ReturnDateTimeString();
                    break;
                case FolderState.GA:
                    fileTo = Application.StartupPath + @"\GA\Backup\"+ReturnDateTimeString();
                    break;
            }

            File.Move(filepath, fileTo);
            return true;

            
        }
    }
}
