﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Xml;
using System.IO;
using System.Windows.Forms;
using System.Data;
using System.Runtime.InteropServices;

namespace Server
{
    public static class XMLAccess
    {
        /// <summary>
        /// 获取xml文档根
        /// </summary>
        /// <param name="xmlpath">xml文件路径</param>
        /// <returns></returns>
        public static XmlNode GetXmlRoot(string xmlpath)
        {
            XmlDocument objXml = new XmlDocument();

            try
            {
                objXml.Load(xmlpath);
            }
            catch (Exception err)
            {
                MessageBox.Show("XML文件路径错误,或XML错误");
                return null;
            }

            return objXml.SelectSingleNode("GARoot");

        }

        /// <summary>
        /// 返回xml文件的所有节点
        /// </summary>
        /// <param name="xmlpath">文件路径</param>
        /// <returns>xmlnodelist</returns>
        public static DataSet GetXmlDataSet(string xmlpath)
        {
            DataSet ds = new DataSet();
            ds.ReadXml(xmlpath);

            return ds;
        }

        /// <summary>
        /// 用结构体构建树节点
        /// </summary>
        /// <param name="attribute"></param>
        /// <returns></returns>
        public static void WriteNodeToTree(TreeAttribute attribute)
        {
            XmlDocument docWrite =new XmlDocument();
            try{
                docWrite.Load(Application.StartupPath + @"\Tree.xml");
            }
            catch
            {
                throw new Exception("Tree文件丢失");
            }
            XmlNode root = docWrite.SelectSingleNode("GARoot/" + attribute.Parent);
            XmlElement xe = docWrite.CreateElement(attribute.Name);

            xe.SetAttribute("Text", attribute.Text);
            xe.SetAttribute("Deep", attribute.Deep.ToString());
            xe.SetAttribute("Parent", attribute.Parent);
            xe.SetAttribute("GAURL", attribute.GAURL);
            xe.SetAttribute("SourceURL", attribute.SouceURL);
            xe.SetAttribute("Extention", attribute.Extention);

            root.AppendChild(xe);
            docWrite.Save(Application.StartupPath + @"\Tree.xml");

        }


        /// <summary>
        /// 编辑节点
        /// </summary>
        /// <param name="attribute"></param>
        public static void EditNodeToTree(TreeAttribute attribute)
        {
            XmlDocument docEdit = new XmlDocument();
            try
            {
                docEdit.Load(Application.StartupPath + @"\Tree.xml");
            }
            catch
            {
                throw new Exception("Tree文件丢失");
            }
            XmlElement xe = (XmlElement)docEdit.SelectSingleNode("GARoot/" + attribute.Parent + "/" + attribute.Name);

            if (xe != null)
            {
                xe.SetAttribute("Text", attribute.Text);
                xe.SetAttribute("Deep", attribute.Deep.ToString());
                xe.SetAttribute("Parent", attribute.Parent);
                xe.SetAttribute("GAURL", attribute.GAURL);
                xe.SetAttribute("SourceURL", attribute.SouceURL);
                xe.SetAttribute("Extention", attribute.Extention);

            }
            docEdit.Save(Application.StartupPath + @"\Tree.xml");
           
        }

        public static bool DelNodeToTree(TreeAttribute attribute)
        { 
              XmlDocument docDel = new XmlDocument();
            try
            {
                docDel.Load(Application.StartupPath + @"\Tree.xml");
            }
            catch
            {
                throw new Exception("Tree文件丢失");
            }
            XmlNode xe = docDel.SelectSingleNode("GARoot/" + attribute.Parent + "/" + attribute.Name);

            if (xe == null)
                return false;
            
            xe.ParentNode.RemoveChild(xe);
            docDel.Save(Application.StartupPath + @"\Tree.xml");

            return true;
        }

    }
}
