﻿using System;
using System.Collections.Generic;
using System.Text;
using ModelSvr;

namespace AnalysisEngine
{
    class DaoEngine
    {

        #region 变量
        private DBInfoList _DBInfoListP;
        public DBInfoList DBInfoListP
        {
            get { return _DBInfoListP; }
            set { _DBInfoListP = value; }
        }

        private ProjectInfo _ProjectInfoP;
        public ProjectInfo ProjectInfoP
        {
            get { return _ProjectInfoP; }
            set { _ProjectInfoP = value; }
        }
        #endregion

        #region 构造函数
        /// <summary>
        /// 有参构造函数
        /// </summary>
        /// <param name="dbinfolist"></param>
        /// <param name="projectinfo"></param>
        public DaoEngine(DBInfoList dbinfolist, ProjectInfo projectinfo)
        {
            _DBInfoListP = dbinfolist;
            _ProjectInfoP = projectinfo;
        }

        /// <summary>
        /// 没有无参构造函数
        /// </summary>
        private DaoEngine() { }

        #endregion

        #region 私有方法

        /// <summary>
        /// 获取主键
        /// </summary>
        private string GetPrimaryKey()
        { 
            foreach(DBInfo data  in _DBInfoListP)
            {
                if (data.PrimeKey)
                    return data.Param;
             }

            return "";
        }

        #endregion

        #region 生成源码的方法

        public string GetDaoReSource()
        {
            if (_ProjectInfoP == null)
                return "ProjectInfo为空，请检查";
            if (_DBInfoListP == null)
                return "DBInfoList为空，请检查";

            string strsource = string.Empty;

            strsource += "#region 版本说明" + "\n";
            strsource += "/*****************************************************************************" + "\n";
            strsource += "* " + "\n";
            strsource += "* 项    目 :" + "\n";
            strsource += "* 作    者 : 成都宇浪科技有限公司 " + "\n";
            strsource += "* 创建时间 : " + DateTime.Now.ToString() + " \n";
            strsource += "*\n";
            strsource += "* Copyright (C) 2010 - 成都宇浪科技有限公司";
            strsource += " * \n";
            strsource += " *****************************************************************************/" + "\n";
            strsource += "#endregion" + "\n\n";

            strsource += "/*\n";
            strsource+="    <daoFactory assembly=\""+_ProjectInfoP.Asemmbly+".dll\">"+"\n";
            strsource += "      <dao\n";
            strsource+="        interface=\""+_ProjectInfoP.Namespace+".I"+_ProjectInfoP.ClassName+"Dao, "+_ProjectInfoP.Namespace+"\""+"\n";
            strsource+="        implementation=\""+_ProjectInfoP.Namespace+"."+_ProjectInfoP.ClassName+"Dao,"+_ProjectInfoP.Namespace+"\" />"+"\n";
            strsource += "    </daoFactory>" + "\n";
            strsource += "*/\n\n";

            strsource += "using System;" + "\n";
            strsource += "using System.Collections;" + "\n";
            strsource += "using System.Text;\n";
            strsource += "using PengeSoft.Data;\n";
            strsource += "using PengeSoft.db;\n";
            strsource+="using PengeSoft.db.IBatis;\n";
            strsource += "using IBatisNet.DataAccess;\n";
            strsource += "using IBatisNet.DataAccess.DaoSessionHandlers;\n";
            strsource += "using IBatisNet.DataAccess.Interfaces;\n";
            strsource += "using IBatisNet.DataMapper;\n\n";

            strsource += "namespace "+_ProjectInfoP.Namespace+ "\n";
            strsource += "{\n";
            strsource += "    /// <summary>\n";
            strsource += "    /// I"+_ProjectInfoP.ClassName+"Dao接口定主义。" + "\n";
            strsource += "    /// </summary>" + "\n";
            strsource += "    public interface I"+_ProjectInfoP.ClassName+"Dao : IDataProvider" + "\n";
            strsource += "    {\n";
            strsource += "    }\n\n";

            strsource += "    /// <summary>\n";
            strsource += "    /// "+_ProjectInfoP.ClassName+"Dao实现, 从BaseSqlMapDao继承。" + "\n";
            strsource += "    /// </summary>" + "\n";
            strsource += "      public class " + _ProjectInfoP.ClassName + "Dao : BaseSqlMapDao,I" + _ProjectInfoP.ClassName + "Dao \n"; //1.2.0版本修复
            strsource += "    {\n";
            strsource += "        #region 私有函数\n\n";
            strsource += "        /// <summary>\n";
            strsource += "        /// 初始化数据对象的Null值属性\n";
            strsource += "        /// </summary>" + "\n";
            strsource+="        /// <param name=\"Data\">数据对象</param>"+"\n";
            strsource += "        private void InitialNullValue(DataPacket Data)" + "\n";
            strsource += "        {\n";
            strsource += "            "+_ProjectInfoP.ClassName+" data = Data as "+_ProjectInfoP.ClassName+";" + "\n";

            foreach(DBInfo data in _DBInfoListP)
            {
                if (!data.PrimeKey && data.IsNotNull)
                    strsource += "            if (data." + data.Param + " == null) data." + data.Param + " = \"\";" + "\n";
            }
            strsource += "        }\n\n";
            strsource += "        #endregion\n\n";
            strsource += "        #region 公共函数\n\n";
            strsource += "        /// <summary>" + "\n";
            strsource += "        /// 根据条件对象取得条件 Hashtable" + "\n";
            strsource += "        /// </summary>" + "\n";
            strsource+="        /// <param name=\"Data\">条件对象</param>"+"\n";
            strsource+="        /// <param name=\"Order\">排序字段</param>"+"\n";
            strsource += "        /// <returns>条件Hashtable</returns>" + "\n";
            strsource += "        public static QueryParameter GetParaHashTable("+_ProjectInfoP.ClassName+" Data, string Order)" + "\n";
            strsource += "        {\n";
            strsource += "            return new "+_ProjectInfoP.ClassName+"QueryPara(Data, Order);" + "\n";
            strsource += "        }\n\n";
            strsource += "        #endregion\n\n";
            strsource += "        #region IPagedDataProvider 成员\n\n";
            strsource += "        /// <summary>\n";
            strsource+="        /// 查询记录数,条件表参见 <see cref=\"PengeSoft.db.IDataProvider\"/>"+"\n";
            strsource += "        /// </summary>" + "\n";
            strsource+="        /// <param name=\"queryPar\">条件表</param>"+"\n";
            strsource += "        /// <returns>记录数</returns>\n";
            strsource += "        public int QueryCount(Hashtable queryPar)" + "\n";
            strsource += "        {\n";
            strsource+="            return QueryCount(\"Query"+_ProjectInfoP.ClassName+"Count\", queryPar);"+"\n";
            strsource += "        }\n";

            strsource+="        /// <summary>\n";
            strsource+="        /// 查询列表,条件表参见 <see cref=\"PengeSoft.db.IDataProvider\"/>"+"\n";
            strsource += "        /// </summary>\n";
            strsource+="        /// <param name=\"queryPar\">条件表</param>"+"\n";
            strsource+="        /// <param name=\"Start\">起始记录</param>"+"\n";
            strsource+="        /// <param name=\"PageSize\">页长度</param>"+"\n";
            strsource += "        /// <returns>列表</returns>" + "\n";
            strsource += "        public DataList QueryList(Hashtable queryPar, int Start, int PageSize)" + "\n";
            strsource += "        {\n";
            strsource+="            return QueryList(\"Query"+_ProjectInfoP.ClassName+"List\", queryPar, Start, PageSize);"+"\n";
            strsource += "        }\n\n";

            strsource += "        /// <summary>\n";
            strsource += "        /// 查询记录数\n";
            strsource += "        /// </summary>\n";
            strsource+="        /// <param name=\"statementName\">sqlMap 映射语句</param>"+"\n";
            strsource+="        /// <param name=\"queryPara\">查询条件对象</param>"+"\n";
            strsource += "        /// <returns>记录数</returns>" + "\n";
            strsource += "        public int QueryCount(string statementName, Hashtable queryPara)" + "\n";
            strsource += "        {\n";
            strsource += "            return (int)ExecuteQueryForObject(statementName, queryPara);" + "\n";
            strsource += "        }\n\n";

            strsource += "        /// <summary>\n";
            strsource += "        /// 查询列表\n";
            strsource += "        /// </summary>\n";
            strsource+="        /// <param name=\"statementName\">sqlMap 映射语句</param>"+"\n";
            strsource+="        /// <param name=\"queryPara\">查询条件对象</param>"+"\n";
            strsource+="        /// <param name=\"Start\">起始记录</param>"+"\n";
            strsource+="        /// <param name=\"PageSize\">页长度</param>"+"\n";
            strsource += "        /// <returns>列表</returns>\n";
            strsource += "        public DataList QueryList(string statementName, Hashtable queryPara, int Start, int PageSize)" + "\n";
            strsource += "        {\n";
            strsource += "            NorDataList list = (NorDataList)ExecuteQueryForList(statementName, queryPara, Start, PageSize);" + "\n\n";
            strsource += "            return list;\n";
            strsource += "        }\n\n";
            strsource += "        #endregion\n\n";

            strsource += "        #region IDataProvider 成员\n\n";
            strsource += "        /// <summary>\n";
            strsource += "        /// 取记录数\n";
            strsource += "        /// </summary>\n";
            strsource += "        public int GetCount()\n";
            strsource += "        {\n";
            strsource += "            Hashtable para = GetParaHashTable(null, null);" + "\n\n";
            strsource += "            return QueryCount(para);\n";
            strsource += "        }\n\n";

            strsource += "        /// <summary>\n";
            strsource += "        /// 取列表\n";
            strsource += "        /// </summary>\n";
            strsource+="        /// <param name=\"Start\">起始记录</param>"+"\n";
            strsource+="        /// <param name=\"PageSize\">页长度</param>"+"\n";
            strsource+="        /// <param name=\"OrderByField\">排序字段</param>"+"\n";
            strsource += "        public DataList GetList(int Start, int PageSize, string OrderByField)" + "\n";
            strsource += "        {\n";
            strsource += "            Hashtable para = GetParaHashTable(null, OrderByField);" + "\n\n";
            strsource += "            return QueryList(para, Start, PageSize);" + "\n";
            strsource += "        }\n\n";

            strsource += "        /// <summary>\n";
            strsource += "        /// 查询记录数\n";
            strsource += "        /// </summary>\n";
            strsource+="        /// <param name=\"Data\">条件对象</param>"+"\n";
            strsource += "        /// <returns>记录数</returns>" + "\n";
            strsource += "        public int QueryCount(DataPacket Data)" + "\n";
            strsource += "        {\n";
            strsource += "            Hashtable para = GetParaHashTable(Data as " + _ProjectInfoP.ClassName + ", null);" + "\n\n";
            strsource+="            return QueryCount(para);"+"\n";
            strsource+="        }\n\n";

            strsource += "        /// <summary>\n";
            strsource += "        /// 查询列表\n";
            strsource += "        /// </summary>\n";
            strsource+="        /// <param name=\"Data\">条件对象</param>\n";
            strsource+="        /// <param name=\"Start\">起始记录</param>"+"\n";
            strsource+="        /// <param name=\"PageSize\">页长度</param>"+"\n";
            strsource += "        /// <returns>列表</returns>" + "\n";
            strsource+="        /// <param name=\"OrderByField\">排序字段</param>"+"\n";
            strsource += "        public DataList QueryList(DataPacket Data, int Start, int PageSize, string OrderByField)" + "\n";
            strsource += "        {\n";
            strsource += "            Hashtable para = GetParaHashTable(Data as "+_ProjectInfoP.ClassName+", OrderByField);" + "\n";
            strsource += "            return QueryList(para, Start, PageSize);" + "\n";
            strsource += "        }\n\n";

            strsource+="        /// <summary>\n";
            strsource += "        /// 添加新记录\n";
            strsource += "        /// </summary>\n";
            strsource+="        /// <param name=\"Data\">数据对象</param>"+"\n";
            strsource += "        /// <returns>返回对象</returns>" + "\n";
            strsource += "        public object Insert(DataPacket Data)" + "\n";
            strsource+="        {\n";
            strsource+="            return Insert(\"Insert"+_ProjectInfoP.ClassName+"\", Data);\n";
            strsource+="        }\n\n";

            strsource += "        /// <summary>\n";
            strsource += "        /// 添加新记录\n";
            strsource += "        /// </summary>\n";
            strsource += "        /// <param name=\"statementName\">sqlMap 映射语句</param>" + "\n";
            strsource+="        /// <param name=\"Data\">数据对象</param>\n";
            strsource+="        /// <returns>返回对象</returns>\n";
            strsource+="        public object Insert(string statementName, DataPacket Data)"+"\n";
            strsource+="        {\n";
            strsource += "            InitialNullValue(Data);\n\n";
            strsource += "            object ret = ExecuteInsert(statementName, Data);" + "\n";
            strsource+="            return ret;"+"\n";
            strsource += "        }\n\n";

            strsource += "        /// <summary>\n";
            strsource += "        /// 更新记录\n";
            strsource += "        /// </summary>\n";
            strsource+="        /// <param name=\"Data\">数据对象</param>\n";
            strsource += "        /// <returns>无</returns>\n";
            strsource += "        public int Update(DataPacket Data)\n";
            strsource += "        {\n";
            strsource+="            return Update(\"Update"+_ProjectInfoP.ClassName+"\", Data);\n";
            strsource += "        }\n\n";

            strsource += "        /// <summary>\n";
            strsource += "        /// 更新记录\n";
            strsource += "        /// </summary>\n";
            strsource+="        /// <param name=\"Data\">数据对象</param>\n";
            strsource+="        /// <param name=\"detail\">更新明细数据</param>\n";
            strsource += "        /// <returns>无</returns>\n";
            strsource += "        public int Update(DataPacket Data, bool detail)" + "\n";
            strsource += "        {\n";
            strsource += "            return Update(\"Update" + _ProjectInfoP.ClassName + "\", Data, detail);\n";
            strsource += "        }\n\n";

            strsource += "        /// <summary>\n";
            strsource += "        /// 更新记录, 指定 sqlMap 映射语句" + "\n";
            strsource += "        /// </summary>\n";
            strsource+="        /// <param name=\"statementName\">sqlMap 映射语句</param>"+"\n";
            strsource+="        /// <param name=\"Data\">数据对象</param>"+"\n";
            strsource += "        /// <returns>更新记录数</returns>\n";
            strsource += "        public int Update(string statementName, DataPacket Data)" + "\n";
            strsource += "        {\n";
            strsource += "            return Update(statementName, Data, true);" + "\n";
            strsource += "        }\n\n";

            strsource += "        /// <summary>\n";
            strsource += "        /// 更新记录, 指定 sqlMap 映射语句\n";
            strsource+="        /// </summary>\n";
            strsource+="        /// <param name=\"statementName\">sqlMap 映射语句</param>"+"\n";
            strsource+="        /// <param name=\"Data\">数据对象</param>"+"\n";
            strsource+="        /// <param name=\"detail\">更新明细数据</param>"+"\n";
            strsource += "        /// <returns>更新记录数</returns>\n";
            strsource += "        public int Update(string statementName, DataPacket Data, bool detail)" + "\n";
            strsource += "        {\n";
            strsource += "            InitialNullValue(Data);\n\n";
            strsource += "            int ret = ExecuteUpdate(statementName, Data);\n\n";
            strsource += "            return ret;\n";
            strsource += "        }\n\n";

            strsource += "        /// <summary>\n";
            strsource += "        /// 取详细数据\n";
            strsource += "        /// </summary>\n";
            strsource+="        /// <param name=\"data\">条件对象</param>\n";
            strsource += "        /// <returns>数据对象</returns>\n";
            strsource += "        public DataPacket GetDetail(DataPacket data)\n";
            strsource += "        {\n";
            strsource += "            return GetDetail(data, true);\n";
            strsource += "        }\n\n";

            strsource += "        /// <summary>\n";
            strsource += "        /// 取数据\n";
            strsource += "        /// </summary>\n";
            strsource+="        /// <param name=\"data\">条件对象</param>"+"\n";
            strsource+="        /// <param name=\"detail\">取明细数据</param>"+"\n";
            strsource += "        /// <returns>数据对象</returns>" + "\n";
            strsource += "        public DataPacket GetDetail(DataPacket data, bool detail)" + "\n";
            strsource += "        {\n";
            strsource+="            return GetDetail(\"Get"+_ProjectInfoP.ClassName+"\", data, detail);"+"\n";
            strsource += "        }\n\n";

            strsource += "        /// <summary>\n";
            strsource += "        /// 取数据\n";
            strsource += "        /// </summary>\n";
            strsource+="        /// <param name=\"statementName\">sqlMap 映射语句</param>"+"\n";
            strsource+="        /// <param name=\"Data\">条件对象</param>"+"\n";
            strsource+="        /// <param name=\"detail\">取明细数据</param>"+"\n";
            strsource += "        /// <returns>数据对象</returns>\n";
            strsource += "        public DataPacket GetDetail(string statementName, DataPacket Data, bool detail)" + "\n";
            strsource += "        {\n";
            strsource += "            return ("+_ProjectInfoP.ClassName+")ExecuteQueryForObject(statementName, Data);" + "\n";
            strsource += "        }\n\n";

            strsource += "        /// <summary>\n";
            strsource += "        /// 删除记录\n";
            strsource+="        /// </summary>\n";
            strsource+="        /// <param name=\"Data\">条件对象</param>"+"\n";
            strsource += "        public void Delete(DataPacket Data)" + "\n";
            strsource += "        {\n";
            strsource+="            ExecuteDelete(\"Delete"+_ProjectInfoP.ClassName+"\", Data);\n";
            strsource += "        }\n\n";
            strsource += "        #endregion\n";
            strsource += "    }\n\n";


            //QueryParameter类的构建

            strsource += "    /// <summary>\n";
            strsource += "    /// "+_ProjectInfoP.ClassName+" 查询参数\n";
            strsource += "    /// </summary>\n";
            strsource += "    public class "+_ProjectInfoP.ClassName+"QueryPara : QueryParameter" + "\n";
            strsource += "    {\n";
            strsource += "        #region 排序常量\n\n";

            foreach (DBInfo data in _DBInfoListP)
            { 
                //支持排序的字段才能排序
                if (data.IsOrderBy)
                {
                    strsource += "        /// <summary>按"+data.Param+"排序</summary>" + "\n";
                    strsource+="        public const string OrderBy"+data.Param+" = \""+data.Param+"\";"+"\n";
                    strsource += "        /// <summary>按"+data.Param+"排序,降序</summary>" + "\n";
                    strsource+="        public const string OrderBy"+data.Param+"_desc = \""+data.Param+"_D\";"+"\n";
                }
            }
            strsource += "\n";
            strsource += "        #endregion\n";

            strsource += "        #region 查询条件常量" + "\n";
            foreach (DBInfo data in _DBInfoListP)
            {
                if (data.IsQuery)
                {
                    strsource += "        /// <summary>查询 "+data.Param+" 条件键名称</summary>" + "\n";
                    strsource+="        public const string QueryKey_"+data.Param+" = \""+data.Param+"\";"+"\n";
                }
            }
            strsource += "\n";
            strsource += "        #endregion\n";

            strsource += "        #region 构造函数\n\n";
            strsource += "        /// <summary>\n";
            strsource += "        /// 构造函数\n";
            strsource += "        /// </summary>\n";
            strsource += "        public "+_ProjectInfoP.ClassName+"QueryPara()"+"\n";
            strsource += "        {\n";
            strsource += "        }\n\n";

            strsource += "        /// <summary>\n";
            strsource += "        /// 构造函数,指定参数对象及排序字段" + "\n";
            strsource += "        /// </summary>\n";
            strsource+="        /// <param name=\"data\">查询参数对象</param>"+"\n";
            strsource+="        /// <param name=\"order\">排序字段</param>"+"\n";
            strsource+="        public "+_ProjectInfoP.ClassName+"QueryPara("+_ProjectInfoP.ClassName+" data, string order)"+"\n";
            strsource+="        {\n";
            strsource+="            SetQueryPara(data, order);\n";
            strsource+="        }\n\n";
            strsource+="        #endregion\n\n";

            strsource += "        #region 公共函数\n\n";
            strsource += "        /// <summary>\n";
            strsource += "        /// 指定查询参数对象及排序字段\n";
            strsource += "        /// </summary>\n";
            strsource+="        /// <param name=\"data\">查询参数对象</param>"+"\n";
            strsource+="        /// <param name=\"order\">排序字段</param>"+"\n";
            strsource += "        public void SetQueryPara("+_ProjectInfoP.ClassName+" data, string order)" + "\n";
            strsource += "        {\n";
            strsource += "            if (data != null)\n";
            strsource += "            {\n";
            foreach (DBInfo data in _DBInfoListP)
            {
                strsource += "                Set"+data.Param+"(data."+data.Param+");" + "\n";

            }
            strsource+="            }\n";
            strsource += "            SetOrderByField(order);" + "\n";
            strsource += "        }\n\n";

            foreach (DBInfo data in _DBInfoListP)
            {
                strsource += "        /// <summary>\n";
                strsource += "        /// 设 " + data.DisplayName + " 条件" + "\n";
                strsource += "        /// </summary>\n";
                strsource+="        /// <param name=\""+data.Param+"\">"+data.DisplayName+"</param>"+"\n";

                if (data.DataType.Contains("Extention"))
                {
                    switch (data.DataType)
                    {
                        case "Extention1":
                            strsource += "        public void Set" + data.Param + "(" + _ProjectInfoP.Extention1 + " " + data.Param + ")" + "\n";
                            break;
                        case "Extention2":
                            strsource += "        public void Set" + data.Param + "(" + _ProjectInfoP.Extention2 + " " + data.Param + ")" + "\n";
                            break;
                        case "Extention3":
                            strsource += "        public void Set" + data.Param + "(" + _ProjectInfoP.Extention3 + " " + data.Param + ")" + "\n";
                            break;
                    }
                }
                else
                    strsource += "        public void Set"+data.Param+"("+data.DataType+" "+data.Param+")" + "\n";
                strsource += "        {\n";
                strsource+="            AddCondition(\""+data.Param+"\", "+data.Param+");"+"\n";
                strsource += "        }\n";

                //时间字段的特殊处理
                if (data.DataType == "DateTime")
                {
                    strsource += "        /// <summary>\n";
                    strsource += "        /// 设 "+data.DisplayName+" 范围条件" + "\n";
                    strsource += "        /// </summary>" + "\n";
                    strsource+="        /// <param name=\"StartDate\">起始日期</param>"+"\n";
                    strsource+="        /// <param name=\"EndDate\">结束日期</param>"+"\n";
                    strsource+="        public void Set"+data.Param+"(DateTime StartDate, DateTime EndDate)"+"\n";
                    strsource+="        {\n";
                    strsource+="            AddDateRange(\""+data.Param+"\", StartDate, EndDate);"+"\n";
                    strsource+="        }\n";

                }
                strsource += "\n";
            }

            strsource += "\n";
            strsource += "        /// <summary>\n";
            strsource += "        /// 设 Sql构建字符串 条件\n";
            strsource += "        /// </summary>\n";
            strsource+="        /// <param name=\"O_SqlBuilder\">Sql构建字符串</param>\n";
            strsource += "        public void SetO_SqlBuilder(string O_SqlBuilder)\n";
            strsource += "        {\n";
            strsource+="            AddCondition(\"O_SqlBuilder\", O_SqlBuilder);\n";
            strsource += "        }\n\n";

            strsource += "        /// <summary>\n";
            strsource += "        /// 设排序字段\n";
            strsource += "        /// </summary>\n";
            strsource+="        /// <param name=\"Order\">排序字段</param>\n";
            strsource += "        public void SetOrderByField(string Order)\n";
            strsource += "        {\n";
            strsource += "            if (!string.IsNullOrEmpty(Order))\n";
            strsource += "            {\n";
            strsource+="                Add(\"_OrderBy\", Order);\n";
            strsource += "            }\n";
            strsource += "        }\n";

            strsource += "        #endregion\n";
            strsource += "    }\n\n";

            //排序比较器
            strsource += "    /// <summary>\n";
            strsource += "    /// "+_ProjectInfoP.ClassName+" 排序比较器\n";
            strsource += "    /// </summary>\n";
            strsource += "    public class Comparer"+_ProjectInfoP.ClassName+" : IComparer\n";
            strsource += "    {\n";
            strsource += "        #region 私有字段\n\n";
            strsource += "        private string _sortField;" + "\n\n";
            strsource += "        #endregion\n\n";

            strsource += "        #region 属性\n\n";
            strsource += "        /// <summary>\n";
            strsource += "        /// 排序字段\n";
            strsource += "        /// </summary>\n";
            strsource += "        public string SortField" + "\n";
            strsource += "        {\n";
            strsource += "            get { return _sortField; }\n";
            strsource += "            set { _sortField = value; }\n";
            strsource += "        }\n\n";
            strsource += "        #endregion\n\n";

            strsource += "        #region 构造函数\n\n";
            strsource += "        /// <summary>\n";
            strsource += "        /// 创建实例,并初始化排序字段\n";
            strsource += "       /// </summary>\n";
            strsource+="        /// <param name=\"sortField\">排序字段</param>"+"\n";
            strsource += "        public Comparer"+_ProjectInfoP.ClassName+"(string sortField)\n";
            strsource += "        {\n";
            strsource += "            _sortField = sortField;" + "\n";
            strsource += "        }\n\n";
            strsource += "        #endregion\n\n";

            strsource += "        #region IComparer 成员\n\n";
            strsource += "        /// <summary>\n";
            strsource+="        /// 比较两个 <see cref=\""+_ProjectInfoP.ClassName+"\"/> 对象并返回一个值，指示一个对象是小于、等于还是大于另一个对象。"+"\n";
            strsource += "        /// </summary>\n";
            strsource+="        /// <param name=\"x\">要比较的第一个对象。</param>"+"\n";
            strsource+="        /// <param name=\"y\">要比较的第二个对象。</param>"+"\n";
            strsource += "        /// <returns>值 条件 小于零 x 小于 y。 零 x 等于 y。 大于零 x 大于 y。</returns>" + "\n";
            strsource += "        public int Compare(object x, object y)\n";
            strsource += "        {\n";
            strsource += "            int ret = 0;\n";
            strsource += "            "+_ProjectInfoP.ClassName+" x1, y1;" + "\n\n";
            strsource += "            x1 = ("+_ProjectInfoP.ClassName+")x;" + "\n";
            strsource += "            y1 = ("+_ProjectInfoP.ClassName+")y;" + "\n\n";
            strsource += "            switch (_sortField)\n";
            strsource += "            {\n";
            foreach (DBInfo data in _DBInfoListP)
            {
                if (!data.PrimeKey)
                {
                    //if (data.DataType == "int" || data.DataType == "DataTime")  1.2版本修改本语句
                    if (data.DataType == "string" || data.DataType == "DataTime")
                    {
                        strsource += "                case " + _ProjectInfoP.ClassName + "QueryPara.OrderBy" + data.Param + ":" + "\n";
                        strsource += "                    ret = " + data.DataType + ".Compare(x1." + data.Param + ", y1." + data.Param + ");" + "\n";
                        strsource += "                    break;\n";
                        strsource += "                case " + _ProjectInfoP.ClassName + "QueryPara.OrderBy" + data.Param + "_desc:" + "\n";
                        strsource += "                    ret = " + data.DataType + ".Compare(y1." + data.Param + ", x1." + data.Param + ");" + "\n";
                        strsource += "                    break;\n";
                    }
                    else 
                    {
                        //ret = Comparer.Default.Compare(x1.isDelete, y1.isDelete);

                        strsource += "                case " + _ProjectInfoP.ClassName + "QueryPara.OrderBy" + data.Param + ":" + "\n";
                        strsource += "                    ret = "+"Comparer.Default.Compare(x1." + data.Param + ", y1." + data.Param + ");" + "\n";
                        strsource += "                    break;\n";
                        strsource += "                case " + _ProjectInfoP.ClassName + "QueryPara.OrderBy" + data.Param + "_desc:" + "\n";
                        strsource += "                    ret = " + "Comparer.Default.Compare(y1." + data.Param + ", x1." + data.Param + ");" + "\n";
                        strsource += "                    break;\n";
                    }
                }
               
            }
            strsource += "                default:\n";
            strsource+="                    throw new Exception(\"未知的排序字段 \" + _sortField);"+"\n";
            strsource += "                    //break;\n";
            strsource += "            }\n\n";
            strsource += "            return ret;\n";
            strsource += "        }\n\n";
            strsource += "        #endregion\n";
            strsource += "    }\n";
            strsource += "}\n";

            return strsource;
        }
        #endregion
    }
}
