﻿using System;
using System.Collections.Generic;
using System.Text;
using ModelSvr;

namespace AnalysisEngine
{
    class DomainEngine
    {
        #region 变量
        private DBInfoList _DBInfoListP;
        public DBInfoList DBInfoListP
        {
            get { return _DBInfoListP; }
            set { _DBInfoListP = value; }
        }

        private ProjectInfo _ProjectInfoP;
        public ProjectInfo ProjectInfoP
        {
            get { return _ProjectInfoP; }
            set { _ProjectInfoP = value; }
        }
        #endregion

        #region 构造函数
        /// <summary>
        /// 有参构造函数
        /// </summary>
        /// <param name="dbinfolist"></param>
        /// <param name="projectinfo"></param>
        public DomainEngine(DBInfoList dbinfolist, ProjectInfo projectinfo)
        {
            _DBInfoListP = dbinfolist;
            _ProjectInfoP = projectinfo;
        }

        /// <summary>
        /// 没有无参构造函数
        /// </summary>
        private DomainEngine() { }

        #endregion

        #region 生成源码的方法

        public string GetDomainReSource()
        {
            if (_ProjectInfoP == null)
                return "ProjectInfo为空，请检查";
            if (_DBInfoListP == null)
                return "DBInfoList为空，请检查";

            string strsource = string.Empty;

            strsource += "#region 版本说明" + "\n";
            strsource += "/*****************************************************************************" + "\n";
            strsource += "* " + "\n";
            strsource += "* 项    目 :" + "\n";
            strsource += "* 作    者 : 成都宇浪科技有限公司 " + "\n";
            strsource += "* 创建时间 : " + DateTime.Now.ToString() + " \n";
            strsource += "*\n";
            strsource += "* Copyright (C) 2010 - 成都宇浪科技有限公司";
            strsource += " * \n";
            strsource += " *****************************************************************************/"+"\n";
            strsource += "#endregion"+"\n\n";

            strsource += "using System;" + "\n";
            strsource += "using System.Collections;" + "\n";
            strsource += "using System.Text;" + "\n";
            strsource += "using PengeSoft.Data;" + "\n";
            strsource += "using PengeSoft.WorkZoneData;" + "\n\n";

            strsource += "namespace " + _ProjectInfoP.Namespace + "\n";
            strsource += "{" + "\n";
            strsource += "    /// <summary>" + "\n";

            if (_ProjectInfoP.Rec)
                strsource += "    /// " + _ProjectInfoP.ClassName + "Rec " + _ProjectInfoP.DisplayName + "的摘要说明。" + "\n";
            else
                strsource += "    /// " + _ProjectInfoP.ClassName + " " + _ProjectInfoP.DisplayName + "的摘要说明。" + "\n";
            strsource += "    /// </summary>" + "\n";

            if (_ProjectInfoP.BaseClass == "NorDataList")
            {
                if (_ProjectInfoP.Rec)
                    strsource += "    public class " + _ProjectInfoP.ClassName + "Rec:" + _ProjectInfoP.BaseClass + "\n";
                else
                    strsource += "    public class " + _ProjectInfoP.ClassName + ":" + _ProjectInfoP.BaseClass + "\n";

                strsource += "    {" + "\n";
                strsource += "        /// <summary>\n";
                strsource += "        /// 初始化新实例 \n";
                strsource += "        /// </summary>\n";
                strsource += "        public "+_ProjectInfoP.BaseClass+"()" + "\n";
                strsource += "        {\n";
                strsource += "            ItemType = typeof(" + _ProjectInfoP.DataType + ");\n";
                strsource += "        }\n\n";
                strsource += "        /// <summary>\n";
                strsource += "        /// 初始化新实例，该实例包含从指定集合复制的元素并且具有与所复制的元素数相同的初始容量。\n";
                strsource += "        /// </summary>\n";
                strsource+="        /// <param name=\"c\"></param>\n";
                strsource += "        public " + _ProjectInfoP.ClassName + "(ICollection c): base(c) \n";
                strsource += "        {\n\n";
                strsource += "            ItemType = typeof("+_ProjectInfoP.DataType+");\n";
                strsource += "        }\n\n";
                strsource += "        #endregion\n";
                strsource += "    }\n";
                strsource += "}\n";
            }
            else
            {    
                if (_ProjectInfoP.Rec)
                    strsource += "    public class " + _ProjectInfoP.ClassName + "Rec:" + _ProjectInfoP.BaseClass + "\n";
                else
                    strsource += "    public class " + _ProjectInfoP.ClassName + ":" + _ProjectInfoP.BaseClass + "\n";

                strsource += "    {" + "\n";
                strsource += "        #region 私有字段" + "\n\n";

                //私有对象自动生成
                foreach (DBInfo item in _DBInfoListP)
                {
                    strsource += "        private ";
                    if (item.DataType.Contains("Extention"))
                    {
                        switch (item.DataType)
                        { 
                            case "Extention1":
                                strsource += _ProjectInfoP.Extention1 + "   ";
                                break;
                            case "Extention2":
                                strsource += _ProjectInfoP.Extention2 + "   ";
                                break;
                            case "Extention3":
                                strsource += _ProjectInfoP.Extention3 + "   ";
                                break;
                        }
                    }
                    else
                        strsource += item.DataType + "   ";
                    strsource += "_" + item.Param;
                    strsource += "      ;      // ";
                    strsource += item.DisplayName + "\n";
                }

                strsource += "\n";
                strsource += "        #endregion" + "\n\n";
                strsource += "        #region 构造函数" + "\n\n";

                strsource += "        /// <summary>" + "\n";
                strsource += "        /// 初始化新实例 " + "\n";
                strsource += "        /// </summary>" + "\n";
                strsource += "        public " + _ProjectInfoP.ClassName + "()" + "\n";
                strsource += "        {" + "\n";

                //******需要对对象类型实例化*******还没有处理
                foreach (DBInfo item in _DBInfoListP)
                {
                    if (item.DataType.Contains("Extention"))
                    { 
                        switch(item.DataType)
                        {
                            case "Extention1":
                                strsource += "            _" + item.Param + "       = new " + _ProjectInfoP.Extention1 + "();" + "\n";
                                break;
                            case "Extention2":
                                strsource += "            _" + item.Param + "       = new " + _ProjectInfoP.Extention2 + "();" + "\n";
                                break;
                            case "Extention3":
                                strsource += "            _" + item.Param + "       = new " + _ProjectInfoP.Extention3 + "();" + "\n";
                                break;
                        }
                       
                    }
                }

                strsource += "        }" + "\n\n";
                strsource += "        #endregion" + "\n\n";

                strsource += "        #region 属性定义" + "\n\n";

                //定制属性
                foreach (DBInfo item in _DBInfoListP)
                {
                    strsource += "        /// <summary>" + "\n";
                    strsource += "        /// " + item.DisplayName + "\n";
                    strsource += "        /// </summary>" + "\n";

                    if (item.DataType.Contains("Extention"))
                    {
                        switch (item.DataType)
                        {
                            case "Extention1":
                                strsource += "        public " +_ProjectInfoP.Extention1 + "           " + item.Param;
                                break;
                            case "Extention2":
                                strsource += "        public " + _ProjectInfoP.Extention2 + "           " + item.Param;
                                break;
                            case "Extention3":
                                strsource += "        public " + _ProjectInfoP.Extention3 + "           " + item.Param;
                                break;
                        }
                    }
                    else
                        strsource += "        public " + item.DataType + "           " + item.Param;
                    strsource += "        { get { return _" + item.Param + "       ;} set { _";
                    strsource += item.Param + "        = value; } }" + "\n";
                }

                strsource += "\n        #endregion\n\n";

                strsource += "        #region 重载公共函数" + "\n\n";
                strsource += "        /// <summary>" + "\n";
                strsource += "        /// 清除所有数据。" + "\n";
                strsource += "        /// </summary>" + "\n";
                strsource += "        public override void Clear()" + "\n";
                strsource += "        {" + "\n";
                strsource += "            base.Clear ();" + "\n\n";

                //清空所有数据的方法实现
                foreach (DBInfo item in _DBInfoListP)
                {
                    switch (item.DataType)
                    {
                        case "int":
                            strsource += "            _" + item.Param + "        = 0;" + "\n";
                            break;
                        case "double":
                            strsource += "            _" + item.Param + "        = 0;" + "\n";
                            break;
                        case "float":
                            strsource += "            _" + item.Param + "        = 0;" + "\n";
                            break;
                        case "DateTime":
                            strsource += "            _" + item.Param + "        = DateTime.MinValue;" + "\n";
                            break;
                        case "bool":
                            strsource += "            _" + item.Param + "        = false;" + "\n";
                            break;
                        case "long":
                            strsource += "            _" + item.Param + "        = 0;" + "\n";
                            break;
                        case "short":
                            strsource += "            _" + item.Param + "        = 0;" + "\n";
                            break;
                        case "byte":
                            strsource += "            _" + item.Param + "        = 0;" + "\n";
                            break;
                        case "string":
                            strsource += "            _" + item.Param + "        = null;" + "\n";
                            break;
                        default:
                            strsource += "            _" + item.Param + "        .Clear();" + "\n";
                            break;
                    }

                }
                strsource += "        }\n\n";

                strsource += "        /// <summary>" + "\n";
                strsource += "        /// 用指定节点序列化整个数据对象。" + "\n";
                strsource += "        /// </summary>" + "\n";
                strsource += "        /// <param name=\"node\">用于序列化的 XmlNode 节点。</param>" + "\n";
                strsource += "        public override void XMLEncode(System.Xml.XmlNode node)" + "\n";
                strsource += "        {\n";
                strsource += "            base.XMLEncode (node);" + "\n\n";

                foreach (DBInfo item in _DBInfoListP)
                {
                    if (item.XmlNode == false && item.XmlAttribute == false)
                    {
                        strsource += "            WriteXMLValue(node, \"" + item.Param + "\", _" + item.Param + ");" + "\n";
                    }
                    if (item.XmlNode == true && item.XmlAttribute == false)
                    {
                        strsource += "            WriteXmlNodeValue(node, \"" + item.Param + "\", _" + item.Param + ");" + "\n";
                    }
                    if (item.XmlNode == false && item.XmlAttribute == true)
                    {
                        strsource += "            WriteXmlAttrValue(node, \"" + item.Param + "\", _" + item.Param + ");" + "\n";
                    }
                    if (item.XmlNode == true && item.XmlAttribute == true)
                    {
                        strsource += "            WriteXmlNodeValue(node, \"" + item.Param + "\", _" + item.Param + ");" + "\n";
                    }
                }
                strsource += "        }\n\n";

                strsource += "        /// <summary>" + "\n";
                strsource += "        /// 用指定节点反序列化整个数据对象。" + "\n";
                strsource += "        /// </summary>" + "\n";
                strsource += "        /// <param name=\"node\">用于反序列化的 XmlNode 节点。</param>" + "\n";
                strsource += "        public override void XMLDecode(System.Xml.XmlNode node)" + "\n";
                strsource += "        {\n";
                strsource += "            base.XMLDecode (node);" + "\n\n";

                foreach (DBInfo item in _DBInfoListP)
                {
                    if (item.XmlNode == false && item.XmlAttribute == false)
                    {
                        strsource += "            ReadXMLValue(node, \"" + item.Param + "\", ref  _" + item.Param + ");" + "\n";
                    }
                    if (item.XmlNode == true && item.XmlAttribute == false)
                    {
                        strsource += "            ReadXmlNodeValue(node, \"" + item.Param + "\", ref _" + item.Param + ");" + "\n";
                    }
                    if (item.XmlNode == false && item.XmlAttribute == true)
                    {
                        strsource += "            ReadXmlAttrValue(node, \"" + item.Param + "\", ref  _" + item.Param + ");" + "\n";
                    }
                    if (item.XmlNode == true && item.XmlAttribute == true)
                    {
                        strsource += "            ReadXmlNodeValue(node, \"" + item.Param + "\", ref  _" + item.Param + ");" + "\n";
                    }
                }
                strsource += "        }\n\n";
                strsource += "        /// <summary>" + "\n";
                strsource += "        /// 复制数据对象" + "\n";
                strsource += "        /// </summary>" + "\n";
                strsource += "        /// <param name=\"sou\">源对象,需从DataPacket继承</param>" + "\n";
                strsource += "        public override void AssignFrom(DataPacket sou)" + "\n";
                strsource += "        {\n";
                strsource += "            base.AssignFrom (sou);\n\n";
                strsource += "            " + _ProjectInfoP.ClassName + " s = sou as " + _ProjectInfoP.ClassName + ";" + "\n";
                strsource += "            if (s != null)" + "\n";
                strsource += "            {\n";

                foreach (DBInfo item in _DBInfoListP)
                {
                    //针对非基本类型有个特殊处理
                    strsource += "                _" + item.Param + "        = s._" + item.Param + "       ;" + "\n";
                }

                strsource += "            }" + "\n";
                strsource += "        }" + "\n\n";
                strsource += "        #endregion" + "\n";
                strsource += "    }\n";
                strsource += "}\n";

            }
            


            return strsource;
        }

        #endregion 

        #region 私有方法
        #endregion
    }
}
