﻿using System;
using System.Collections.Generic;
using System.Text;
using ModelSvr;

namespace AnalysisEngine
{
    class ServerExEngine
    {
      #region 变量
        private DBInfoList _DBInfoListP;
        public DBInfoList DBInfoListP
        {
            get { return _DBInfoListP; }
            set { _DBInfoListP = value; }
        }

        private ProjectInfo _ProjectInfoP;
        public ProjectInfo ProjectInfoP
        {
            get { return _ProjectInfoP; }
            set { _ProjectInfoP = value; }
        }
        #endregion

        #region 构造函数
        /// <summary>
        /// 有参构造函数
        /// </summary>
        /// <param name="dbinfolist"></param>
        /// <param name="projectinfo"></param>
        public ServerExEngine(DBInfoList dbinfolist, ProjectInfo projectinfo)
        {
            _DBInfoListP = dbinfolist;
            _ProjectInfoP = projectinfo;
        }

        /// <summary>
        /// 没有无参构造函数
        /// </summary>
        private ServerExEngine() { }

        #endregion

        #region 私有方法

        /// <summary>
        /// 获取主键
        /// </summary>
        private string GetPrimaryKey()
        {
            foreach (DBInfo data in _DBInfoListP)
            {
                if (data.PrimeKey)
                    return data.Param;
            }

            return "";
        }

        #endregion

        #region 生成源码的方法

        public string GetServerExReSource()
        {
             if (_ProjectInfoP == null)
                return "ProjectInfo为空，请检查";
            if (_DBInfoListP == null)
                return "DBInfoList为空，请检查";

            string strsource = string.Empty;

            strsource += "#region 版本说明" + "\n";
            strsource += "/*****************************************************************************" + "\n";
            strsource += "* " + "\n";
            strsource += "* 项    目 :" + "\n";
            strsource += "* 作    者 : 成都宇浪科技有限公司 " + "\n";
            strsource += "* 创建时间 : " + DateTime.Now.ToString() + " \n";
            strsource += "*\n";
            strsource += "* Copyright (C) 2010 - 成都宇浪科技有限公司";
            strsource += " * \n";
            strsource += " *****************************************************************************/" + "\n";
            strsource += "#endregion" + "\n\n";

            strsource += @"/*" + "\n";
            strsource += "      <component id=\"" + _ProjectInfoP.ClassName + "SvrEx\" type=\"" + _ProjectInfoP.Namespace + "." + _ProjectInfoP.ClassName + "SvrEx," + _ProjectInfoP.Asemmbly + "\"" + " service=\"" + _ProjectInfoP.Namespace + ".I" + _ProjectInfoP.ClassName + "SvrEx" + "," + _ProjectInfoP.Asemmbly + "\"" + " lifestyle=\"Singleton\">" + "\n";
            strsource += "        <parameters>" + "\n";
            strsource += "        </parameters>" + "\n";
            strsource += "      </component>" + "\n";
            strsource += "*/" + "\n";
            strsource += "using System;" + "\n";
            strsource += "using System.Collections;" + "\n";
            strsource += "using System.Text;" + "\n\n";
            
            strsource += "namespace " + _ProjectInfoP.Namespace + "\n";
            strsource += "{\n";

            strsource += "    public interface I" + _ProjectInfoP.ClassName + "SvrEx : I" + _ProjectInfoP.ClassName + "Svr"+"\n";
            strsource += "    {\n";
            strsource += "        void Add("+_ProjectInfoP.ClassName+" data);" + "\n";
            strsource += "        void Del(string guid);"+"\n";
            strsource += "        void Update"+_ProjectInfoP.ClassName+"("+_ProjectInfoP.ClassName+" data);" + "\n";
            strsource += "        "+_ProjectInfoP.ClassName+" Get(string guid);" + "\n";
            strsource += "    }\n\n";

            strsource += "    public class "+_ProjectInfoP.ClassName+"SvrEx : "+_ProjectInfoP.ClassName+"Svr, I"+_ProjectInfoP.ClassName+"SvrEx"+"\n";
            strsource += "    {\n";
            strsource += "        #region I"+_ProjectInfoP.ClassName+"SvrEx 成员" + "\n";
            strsource += "        public void Add("+_ProjectInfoP.ClassName+" data)" + "\n";
            strsource += "        {\n";
            strsource += "            Insert(data);" + "\n";
            strsource += "        }" + "\n\n";

            strsource += "        public void Del(string guid)" + "\n";
            strsource += "        {\n";
            strsource += "            "+_ProjectInfoP.ClassName+" data = Get(guid);\n";
            strsource += "            Delete(data);\n";
            strsource += "        }\n\n";

            strsource += "        public void Update"+_ProjectInfoP.ClassName+"("+_ProjectInfoP.ClassName+" data)" + "\n";
            strsource += "        {\n";
            foreach (DBInfo item in _DBInfoListP)
            {
                if (item.PrimeKey)
                {
                    strsource += "            " + _ProjectInfoP.ClassName + " info = Get(data."+item.Param+");" + "\n";
                    break;
                }
            }
            strsource += "            if (info != null)" + "\n";
            strsource += "            {\n";
            foreach (DBInfo item in _DBInfoListP)
            {
                if(!item.PrimeKey)
                    strsource += "                info."+item.Param+" = data."+item.Param+";"+"\n";
            }
            strsource += "\n";

            strsource += "                Update(info);"+"\n";
            strsource += "            }\n";
            strsource += "        }\n\n";

            strsource += "        public "+_ProjectInfoP.ClassName+" Get(string guid)\n";
            strsource += "        {\n";
            strsource += "            "+_ProjectInfoP.ClassName+" data = new "+_ProjectInfoP.ClassName+"();\n";

            foreach (DBInfo item in _DBInfoListP)
            {
                if (item.PrimeKey)
                    strsource += "            data."+item.Param+" = guid;\n\n";
            }

            strsource += "            return GetDetail(data) as "+_ProjectInfoP.ClassName+";" + "\n";
            strsource += "        }\n\n";
            strsource += "        #endregion\n";

            strsource += "    }\n";
            strsource += "}\n";

            return strsource;
        }
    }
}
        #endregion