﻿using System;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Windows.Forms;
using System.Runtime.InteropServices;
using HWND = System.IntPtr;
using System.IO;

namespace BRichTextBoxEx
{
    /// <summary>
    /// 在BRichTextBox基础上扩展，实现模型语言编辑器只能感知功能
    /// </summary>
    public partial class BRichTextBoxEx : System.Windows.Forms.RichTextBox
    {

        int line;
        private Parser parser;
        /// <summary>        
        /// 必需的设计器变量。       
        /// /// </summary>        
        //使用win32api：SendMessage来防止控件着色时的闪烁现象        
        [DllImport("user32")]
        private static extern int SendMessage(HWND hwnd, int wMsg, int wParam, IntPtr lParam);
        private const int WM_SETREDRAW = 0xB;

        public BRichTextBoxEx()
        {
            InitializeComponent();
            base.WordWrap = false;

            //判断3个文件是否存在
            if (!File.Exists("Object.xml"))
            {
                MessageBox.Show("检测到配置文件Object.xml不存在", "警告", MessageBoxButtons.OK, MessageBoxIcon.Warning);
            }
        }

        //重写基类的OnTextChanged方法。为了提高效率，程序是对当前文本插入点所在行进行扫描，        
        //以空格为分割符，判断每个单词是否为关键字，并进行着色。       
        protected override void OnTextChanged(EventArgs e)
        {
            if (base.Text != "")
            {
                int selectStart = base.SelectionStart;
                line = base.GetLineFromCharIndex(selectStart); //获取行号
                string lineStr = base.Lines[line];    //获取文本行的文本           
                int linestart = 0;
                for (int i = 0; i < line; i++)
                {
                    linestart += base.Lines[i].Length + 1;
                }
                SendMessage(base.Handle, WM_SETREDRAW, 0, IntPtr.Zero);
                base.SelectionStart = linestart;
                base.SelectionLength = lineStr.Length;
                base.SelectionColor = Color.Black;
                base.SelectionStart = selectStart;
                base.SelectionLength = 0;

                //获取当前行的单词  
                //添加 <> / " ，适应xml
                string[] words = lineStr.Split(new char[] { ' ', '.', '\n', '(', ')', '}', '{', '"', '[', ']', '<', '>', '/', '"','='});

                parser = new Parser();
                for (int i = 0; i < words.Length; i++)//一个字符段一个字符段来判断          
                {
                    //判断是否是程序保留字 是的话高亮显示         
                    if (parser.IsKeyWord(words[i]) != Color.Empty)
                    {
                        int length = 0;
                        for (int j = 0; j < i; j++)
                        {
                            length += words[j].Length;
                        }
                        length += i;
                        int index = lineStr.IndexOf(words[i], length);
                        base.SelectionStart = linestart + index;
                        base.SelectionLength = words[i].Length;
                
                        base.SelectionColor = parser.IsKeyWord(words[i]);
                        base.SelectionFont = parser.IsKeyWordEx(words[i]);

                        base.SelectionStart = selectStart;
                        base.SelectionLength = 0;
                        base.SelectionColor = Color.Black;
                    }
                }
                SendMessage(base.Handle, WM_SETREDRAW, 1, IntPtr.Zero);
                base.Refresh();
            } base.OnTextChanged(e);
        }

        /// <summary>
        /// 是否自动换行
        /// </summary>
        public new bool WordWrap
        {
            get { return base.WordWrap; }
            set { base.WordWrap = value; }
        }

        private void toolFind_Click(object sender, EventArgs e)
        {
            frmFind find = new frmFind(this);
            find.Show();
            

            
        }
    }
}