﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Forms;
using System.IO;

namespace FileOperSvr
{
    /// <summary>
    /// 文件操作接口
    /// </summary>
    public interface IFileOperSvr
    {
        /// <summary>
        /// 新建
        /// </summary>
        /// <returns></returns>
        void New(RichTextBox _rich);

        /// <summary>
        /// 打开
        /// </summary>
        /// <returns></returns>
        bool Open(RichTextBox _rich);

        /// <summary>
        /// 保存
        /// </summary>
        /// <returns></returns>
        bool Save(RichTextBox _rich);

        /// <summary>
        /// 另存为
        /// </summary>
        /// <returns></returns>
        Boolean SaveAs(RichTextBox _rich);

        /// <summary>
        /// 另存为2
        /// </summary>
        /// <returns></returns>
        Boolean SaveAs2(RichTextBox _rich);
    }

    public enum ECurrentSate
    {
        未知 = 0,
        新建 = 1,
        保存 = 2,

    }

    /// <summary>
    /// 文件操作类
    /// </summary>
    public class FileOperSvr : IFileOperSvr
    {
        private static FileOperSvr _svr = null;

        /// <summary>
        /// 控制对文件新建保存等操作
        /// </summary>
        private ECurrentSate _currentFileType;

        public ECurrentSate CurrentFileType
        {
            get { return _currentFileType; }
            set { _currentFileType = value; }
        }

        /// <summary>
        /// 需要保存路径是否已经被保存下来
        /// </summary>
        private string _filepath = "";

        public string FilePath
        {
            get { return _filepath; }
            set { _filepath = value; }
        }


        private FileOperSvr()
        {

        }

        public static FileOperSvr Instance()
        {
            if (_svr == null)
            {
                FileOperSvr _svrEx = new FileOperSvr();
                _svrEx.CurrentFileType = ECurrentSate.新建;
                return _svrEx;
            }
            else return _svr;
        }

        /// <summary>
        /// 新建
        /// </summary>
        /// <returns></returns>
        public void New(RichTextBox _rich)
        {
            if (_currentFileType == ECurrentSate.保存)
            {
                DialogResult result = MessageBox.Show("在新建文件前将保存对当前文件的保存，你确定吗", "文件保存提示", MessageBoxButtons.YesNoCancel, MessageBoxIcon.Information);
                if (result == DialogResult.Cancel)
                {
                    return;
                }

                if (result == DialogResult.Yes)
                {
                    Save(_rich);

                    if (_rich != null)
                        _rich.Text = IOAccess.GetWordText(Application.StartupPath + @"/Templates/NewTmp.txt");

                    _filepath = "";
                    _currentFileType = ECurrentSate.新建;


                }

                if (result == DialogResult.No)
                {
                    if (_rich != null)
                        _rich.Text = "";

                    _filepath = "";
                    _currentFileType = ECurrentSate.新建;
                }

            }
            else
            {
                if (_rich != null)
                    _rich.Text = IOAccess.GetWordText(Application.StartupPath + @"/Templates/NewTmp.txt");

                _filepath = "";
                _currentFileType = ECurrentSate.新建;

            }
        }


        /// <summary>
        /// 打开
        /// </summary>
        /// <returns></returns>
        public bool Open(RichTextBox _rich)
        {
            if (_currentFileType == ECurrentSate.保存)
            {
                DialogResult result = MessageBox.Show("在打开文件前将保存对当前文件的保存，你确定吗", "文件保存提示", MessageBoxButtons.YesNoCancel, MessageBoxIcon.Information);
                if (result == DialogResult.Cancel)
                {
                    return true;
                }

                if (result == DialogResult.Yes)
                {
                    Save(_rich);
                }

                if (result == DialogResult.No)
                {
                    if (_rich != null)
                        _rich.Text = IOAccess.GetWordText(Application.StartupPath + @"/Templates/NewTmp.txt");
                }

                _filepath = "";
                _currentFileType = ECurrentSate.保存;

            }
            _rich.Text = IOAccess.GetWordText(Application.StartupPath + @"/Templates/NewTmp.txt");

            OpenFileDialog openDialog = new OpenFileDialog();
            //初始化路径,可通过XML扩展
            openDialog.InitialDirectory = Application.StartupPath;
            openDialog.Title = "请选择模型文件";
            //文件类型，可通过XML扩展
            openDialog.Filter = "BLModel(*.blm)|*.blm";
            openDialog.RestoreDirectory = true;
            openDialog.FilterIndex = 0;

            if (openDialog.ShowDialog() == DialogResult.OK)
            {
                _rich.Text = File.ReadAllText(openDialog.FileName);
                _rich.AppendText("\n");

                //定制
                _filepath = openDialog.FileName;
                _currentFileType = ECurrentSate.保存;
                return true;
            }
            return false;
        }

        /// <summary>
        /// 保存
        /// </summary>
        /// <returns></returns>
        public bool Save(RichTextBox _rich)
        {
            if (_currentFileType == ECurrentSate.保存)
            {
                if (_filepath != "")
                {
                    _rich.SaveFile(_filepath, RichTextBoxStreamType.PlainText);
                    _currentFileType = ECurrentSate.新建;

                }
                else
                {
                    return SaveAs(_rich);

                }
            }

            return false;
        }

        /// <summary>
        /// 另存为
        /// </summary>
        /// <returns></returns>
        public Boolean SaveAs(RichTextBox _rich)
        {
            if (_currentFileType == ECurrentSate.保存)
            {
                SaveFileDialog saveDialog = new SaveFileDialog();
                //初始化路径,可通过XML扩展
                saveDialog.InitialDirectory = Application.StartupPath;
                saveDialog.Title = "请选择模型文件的位置";
                //文件类型，可通过XML扩展
                saveDialog.Filter = "BLModel(*.blm)|*.blm";
                saveDialog.RestoreDirectory = true;
                saveDialog.FilterIndex = 0;

                if (saveDialog.ShowDialog() == DialogResult.OK)
                {
                    _filepath = saveDialog.FileName;
                    Save(_rich);

                    return true;
                }

                return true;

            }
            return false;
        }


        /// <summary>
        /// 另存为2
        /// </summary>
        /// <returns></returns>
        public Boolean SaveAs2(RichTextBox _rich)
        {
            SaveFileDialog saveDialog = new SaveFileDialog();
            //初始化路径,可通过XML扩展
            saveDialog.InitialDirectory = Application.StartupPath;
            saveDialog.Title = "请选择模型文件的位置";
            //文件类型，可通过XML扩展
            saveDialog.Filter = "BLModel(*.blm)|*.blm";
            saveDialog.RestoreDirectory = true;
            saveDialog.FilterIndex = 0;

            if (saveDialog.ShowDialog() == DialogResult.OK)
            {
                _filepath = saveDialog.FileName;
                _rich.SaveFile(saveDialog.FileName, RichTextBoxStreamType.PlainText);
            }

            return true;

        }



    }
}
