﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using TreeMgeSvr;
using System.Xml;
using ModelSvr;
using System.Collections;
using System.IO;
using AnalysisEngine;
using FileOperSvr;

namespace VisualFramework_Single
{
    public partial class frmMain : Form
    {
        public frmMain()
        {
            InitializeComponent();
        }

        #region 变量属性
        //右键选中节点
        private TreeNode _tnRightKey = null;
        public TreeNode tnRightKey
        {
            get { return _tnRightKey; }
            set { _tnRightKey = value; }
        }

        //右键选中节点
        private TreeNode _tnLeftKey = null;
        public TreeNode tnLeftKey
        {
            get { return _tnLeftKey; }
            set { _tnLeftKey = value; }
        }

        //当前文件的状态
        private int _CurrentState;
        public int CurrentState
        {
            get { return _CurrentState; }
            set { _CurrentState = value; }
        }

        //保存文件的路径
        private string _CurrentFilePath;
        public string CurrentFilePath
        {
            get { return _CurrentFilePath; }
            set { _CurrentFilePath = value; }
        }



        /// <summary>
        /// 获取模型文本
        /// </summary>
        //public string ModelText
        //{
        //    get { return GetModelText(); }
        //}

       

        #endregion


        #region 窗体事件

        /// <summary>
        /// 初始化
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void frmMain_Load(object sender, EventArgs e)
        {
            this.splitContainerInner.SplitterDistance = (int)(this.Width * 0.2);
            //设置模型设计的文本框大小
            SetModelTextSize();

            //构建树
            CreateTreeView();
            //初始化状态为新建
            _CurrentState = (int)ECurrentSate.新建;
            //设置最近打开文件
            SetInitCurrentOpenFilePath();
        }

        private void frmMain_SizeChanged(object sender, EventArgs e)
        {
            //
        }

        /// <summary>
        /// 窗体关闭的时候检测
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void frmMain_FormClosing(object sender, FormClosingEventArgs e)
        {

            if (_CurrentState == (int)ECurrentSate.新建)
            {
                e.Cancel = false;
                Dispose();
            }
            else
            {
                //弹出保存框
                DialogResult result = MessageBox.Show("在关闭程序前你还有未保存的文件，你确定要保存吗？", "文件保存提示", MessageBoxButtons.YesNoCancel, MessageBoxIcon.Information);

                if (result == DialogResult.Yes)
                {
                    SaveFileDialog saveDialog = new SaveFileDialog();
                    //初始化路径,可通过XML扩展
                    saveDialog.InitialDirectory = Application.StartupPath;
                    saveDialog.Title = "请选择模型文件的位置";
                    //文件类型，可通过XML扩展
                    saveDialog.Filter = "BLModel(*.blm)|*.blm";
                    saveDialog.RestoreDirectory = true;
                    saveDialog.FilterIndex = 0;

                    if (saveDialog.ShowDialog() == DialogResult.OK)
                    {
                        FileOperSvr.IOAccess.WriteFile(saveDialog.FileName, GetModelText());
                    }

                    e.Cancel = false;
                    Dispose();
                }
                if (result == DialogResult.Cancel)
                {
                    e.Cancel = true;
                    return;
                }

                if (result == DialogResult.No)
                {
                    e.Cancel = false;
                    Dispose();
                    return;
                }
                
            }
        }

        #endregion


        #region 公共方法

        /// <summary>
        /// 设置模型设计的文本框大小
        /// </summary>
        private void SetModelTextSize()
        {
            double baseCount = (120) * this.Width / 800.0;

            this.txtAssembly.Width = (int)baseCount;
            this.cmbBaseClass.Width = (int)baseCount;
            this.txtChildDataType.Width = (int)baseCount;
            this.txtClassName.Width = (int)baseCount;
            this.txtDataTableName.Width = (int)baseCount;
            this.txtName.Width = (int)baseCount;
            this.txtNameSpace.Width = (int)baseCount;
            this.txtShowName.Width = (int)baseCount;
            this.txtTabChildType.Width = (int)baseCount;
            this.txtType.Width = (int)baseCount;

            this.treeTemplate.Width = (int)baseCount;

            //this.pnlExtention.Width = (int)baseCount;

            //参数
            baseCount = (150) * this.Width / 800.0;
            baseCount -= 120;
            baseCount = (150) * this.Width / 800.0;
        }

        /// <summary>
        /// 构建树
        /// </summary>
        public void CreateTreeView()
        {
            this.treeTemplate.Nodes.Clear();

            XmlNode xn =XmlHelper.GetXmlRoot("Tree.xml");
            //处理节点
            if (xn.NodeType == XmlNodeType.Element)
            {
                TreeAttribute attribute = new TreeAttribute();

                attribute.Name = xn.Name;
                attribute.Text = xn.Attributes["Text"].Value;
                attribute.Deep = Int32.Parse(xn.Attributes["Deep"].Value);
                attribute.Parent = xn.Attributes["Parent"].Value;
                attribute.Comment = xn.Attributes["Comment"].Value;
                attribute.Tag = xn.Attributes["Tag"].Value;
                

                if (attribute.Deep < 1 && attribute.Deep > 3)
                    return;

                if (attribute.Deep == 1)
                {
                    TreeNode Root = new TreeNode();

                    Root.Text = attribute.Text;
                    Root.Tag = attribute as object;
                    Root.ToolTipText = attribute.Comment;
                    Root.ForeColor = Color.Red;

                    treeTemplate.Nodes.Add(Root);
                    GetTreeViewChild(attribute.Name, Root, attribute.Deep);  //获取孩子节点
                }

                //if (attribute.Deep == 2)
                //{
                //    TreeNode Root = new TreeNode();

                //    Root.Text = attribute.Text;
                //    Root.Tag = attribute as object;
                //    Root.ToolTipText = attribute.Comment;
                //    Root.ForeColor = Color.Red;

                //    treeTemplate.Nodes.Add(Root);
                //    GetTreeViewChild(attribute.Name, Root, attribute.Deep);  //获取孩子节点
                //}
            }

        }

        //获取孩子节点
        public void GetTreeViewChild(string parent, TreeNode Root, int Deep)
        {
            DataSet ds = XmlHelper.GetXmlDataSet("Tree.xml");

            for (int i = 0; i < ds.Tables.Count; i++)
            {
                TreeAttribute attribute = new TreeAttribute();

                attribute.Name = ds.Tables[i].TableName;
                attribute.Text = ds.Tables[i].Rows[0]["Text"].ToString();
                attribute.Deep = Int32.Parse(ds.Tables[i].Rows[0]["Deep"].ToString());
                attribute.Parent = ds.Tables[i].Rows[0]["Parent"].ToString();
                attribute.Comment = ds.Tables[i].Rows[0]["Comment"].ToString();
                attribute.Tag = ds.Tables[i].Rows[0]["Tag"].ToString();

                if (attribute.Deep < 1 && attribute.Deep > 3)
                    break;

                if ((attribute.Parent == parent && (attribute.Deep - Deep == 1)))
                {
                    TreeNode Node = new TreeNode();

                    Node.Text = attribute.Text;
                    Node.Tag = attribute as object;
                    Node.ToolTipText = attribute.Comment;
                    if (attribute.Deep == 2)
                        Node.ForeColor = Color.Red;
                    if (attribute.Deep >= 3)
                        Node.ForeColor = Color.Blue;

                    Root.Nodes.Add(Node);

                    Root.Expand();
                    GetTreeViewChild(attribute.Name, Node, attribute.Deep);
                }

            }
        }
        #endregion

        #region 菜单事件
        /// <summary>
        /// 菜单功能描述
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void menuTreeNode_item_Description_Click(object sender, EventArgs e)
        {
            if (_tnRightKey == null)
            {
                MessageBox.Show("你选择的节点错误！");
                return;
            }
            TreeAttribute attribute = _tnRightKey.Tag as TreeAttribute;
            MessageBox.Show("说明:" + attribute.Comment, attribute.Text, MessageBoxButtons.OK, MessageBoxIcon.Asterisk);
        }


        /// <summary>
        /// 生成文件
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void menuTreeNode_item_BuildFile_Click(object sender, EventArgs e)
        {
            if (_tnRightKey == null)
            {
                MessageBox.Show("你选择的节点错误！");
                return;
            }

            //保存文件
            BulidFile();
            
            
        }

        /// <summary>
        /// 生成全部文件
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void menuTreeNode_item_BuildAllFiles_Click(object sender, EventArgs e)
        {
            //保存全部文件
            BulidFileEx();
        }

        /// <summary>
        /// 打开版本文件
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void itemVersion_Click(object sender, EventArgs e)
        {
            System.Diagnostics.Process.Start("版本说明.txt");
        }


        /// <summary>
        /// 最近打开
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void menu_item_Curr1_Click(object sender, EventArgs e)
        {
            OpenCurrentFile(menu_item_Curr1.Text);
        }
      

        /// <summary>
        /// 最近打开
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void menu_item_Curr2_Click(object sender, EventArgs e)
        {
            OpenCurrentFile(menu_item_Curr2.Text);
        }

        /// <summary>
        /// 最近打开
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void menu_item_Curr3_Click(object sender, EventArgs e)
        {
            OpenCurrentFile(menu_item_Curr3.Text);
        }

        /// <summary>
        /// 最近打开
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void menu_item_Curr4_Click(object sender, EventArgs e)
        {
            OpenCurrentFile(menu_item_Curr4.Text);

        }

        /// <summary>
        /// 最近打开
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void menu_item_Curr5_Click(object sender, EventArgs e)
        {
            OpenCurrentFile(menu_item_Curr5.Text);

        }

        /// <summary>
        /// 新建
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void menu_item_New_Click(object sender, EventArgs e)
        {
            //清空路径
            _CurrentFilePath = "";
            this.Text = "VisualFramework Beta 1.6";


            if (_CurrentState == (int)ECurrentSate.新建)
            {
                ClearProjectInfo();
                ucDBDesign1.ClearGridView();
            }
            else
            {
                //弹出保存框
                DialogResult result = MessageBox.Show("在新建文件前将保存对当前文件的保存，你确定吗", "文件保存提示", MessageBoxButtons.YesNoCancel, MessageBoxIcon.Information);
               
                if (result == DialogResult.Yes)
                {
                    SaveFileDialog saveDialog = new SaveFileDialog();
                    //初始化路径,可通过XML扩展
                    saveDialog.InitialDirectory = Application.StartupPath;
                    saveDialog.Title = "请选择模型文件的位置";
                    //文件类型，可通过XML扩展
                    saveDialog.Filter = "BLModel(*.blm)|*.blm";
                    saveDialog.RestoreDirectory = true;
                    saveDialog.FilterIndex = 0;

                    if (saveDialog.ShowDialog() == DialogResult.OK)
                    {
                        FileOperSvr.IOAccess.WriteFile(saveDialog.FileName, GetModelText());
                    }
                }

                //恢复新建状态
                _CurrentState = 1;
                ClearProjectInfo();
                ucDBDesign1.ClearGridView();

                
            }
        }

        /// <summary>
        /// 打开
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void menu_item_Open_Click(object sender, EventArgs e)
        {
            if (_CurrentState == (int)ECurrentSate.保存)
            {
                DialogResult result = MessageBox.Show("在打开文件前将保存对当前文件的保存，你确定吗", "文件保存提示", MessageBoxButtons.YesNoCancel, MessageBoxIcon.Information);

                if (result == DialogResult.Yes)
                {
                    SaveFileDialog saveDialog = new SaveFileDialog();
                    //初始化路径,可通过XML扩展

                    string openpath = GetLastOpenPath();

                    if(!string.IsNullOrEmpty(openpath))
                        saveDialog.InitialDirectory =GetLastOpenPath(); //Application.StartupPath;
                    else
                        saveDialog.InitialDirectory =Application.StartupPath;


                    saveDialog.Title = "请选择模型文件的位置";
                    //文件类型，可通过XML扩展
                    saveDialog.Filter = "BLModel(*.blm)|*.blm";
                    saveDialog.RestoreDirectory = true;
                    saveDialog.FilterIndex = 0;

                    if (saveDialog.ShowDialog() == DialogResult.OK)
                    {
                        FileOperSvr.IOAccess.WriteFile(saveDialog.FileName, GetModelText());
                        SetLastOpenPath(saveDialog.FileName);
                    }

                    
                }

            }

            //打开的操作

            OpenFileDialog openDialog = new OpenFileDialog();
            //初始化路径,可通过XML扩展
            string path = GetLastOpenPath();
            if (!string.IsNullOrEmpty(path))
                openDialog.InitialDirectory = path; //Application.StartupPath;
            else
                openDialog.InitialDirectory = Application.StartupPath;
            openDialog.Title = "请选择模型文件";
            //文件类型，可通过XML扩展
            openDialog.Filter = "BLModel(*.blm)|*.blm";
            openDialog.RestoreDirectory = true;
            openDialog.FilterIndex = 0;

            if (openDialog.ShowDialog() == DialogResult.OK)
            {
                //加载模型
                try
                {
                    LoadModel(openDialog.FileName);
                }
                catch(Exception err)
                {
                    MessageBox.Show("你加载的模型有错，请检查！\n以下是系统返回的信息"+err.ToString());
                }

               //存储路径
                _CurrentFilePath = openDialog.FileName;
                this.Text = _CurrentFilePath;
                SetLastOpenPath(_CurrentFilePath);

                SetCurrentOpenFilePath(_CurrentFilePath);
                //设置最近打开文件
                SetInitCurrentOpenFilePath();
            }
        }

         /// <summary>
        /// 保存
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void menu_item_Save_Click(object sender, EventArgs e)
        {
            ucDBDesign1.Focus();
            if (!string.IsNullOrEmpty(_CurrentFilePath))
            {
                //保存
                FileOperSvr.IOAccess.WriteFile(_CurrentFilePath, GetModelText());

                SetLastOpenPath(_CurrentFilePath);

                _CurrentState = (int)ECurrentSate.新建;
            }
            else
            {
                SaveFileDialog saveDialog = new SaveFileDialog();
                //初始化路径,可通过XML扩展
                string openpath = GetLastOpenPath();

                if (!string.IsNullOrEmpty(openpath))
                    saveDialog.InitialDirectory = GetLastOpenPath(); //Application.StartupPath;
                else
                    saveDialog.InitialDirectory = Application.StartupPath;

                saveDialog.Title = "请选择模型文件的位置";
                //文件类型，可通过XML扩展
                saveDialog.Filter = "BLModel(*.blm)|*.blm";
                saveDialog.RestoreDirectory = true;
                saveDialog.FilterIndex = 0;

                if (saveDialog.ShowDialog() == DialogResult.OK)
                {
                    FileOperSvr.IOAccess.WriteFile(saveDialog.FileName, GetModelText());
                    _CurrentState = (int)ECurrentSate.新建;

                    _CurrentFilePath = saveDialog.FileName;

                    SetLastOpenPath(_CurrentFilePath);



                    this.Text = _CurrentFilePath;

                    //控制保存最近打开
                    SetCurrentOpenFilePath(_CurrentFilePath);
                    //设置最近打开文件
                    SetInitCurrentOpenFilePath();
                }

               
            }

        }

        /// <summary>
        /// 另存为
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void menu_item_SaveAs_Click(object sender, EventArgs e)
        {
            SaveFileDialog saveDialog = new SaveFileDialog();
            //初始化路径,可通过XML扩展
            string openpath = GetLastOpenPath();

            if (!string.IsNullOrEmpty(openpath))
                saveDialog.InitialDirectory = GetLastOpenPath(); //Application.StartupPath;
            else
                saveDialog.InitialDirectory = Application.StartupPath;
            saveDialog.Title = "请选择模型文件的位置";
            //文件类型，可通过XML扩展
            saveDialog.Filter = "BLModel(*.blm)|*.blm";
            saveDialog.RestoreDirectory = true;
            saveDialog.FilterIndex = 0;

            if (saveDialog.ShowDialog() == DialogResult.OK)
            {
                FileOperSvr.IOAccess.WriteFile(saveDialog.FileName, GetModelText());
                //_CurrentState = (int)ECurrentSate.新建;
                SetLastOpenPath(saveDialog.FileName);

                SetCurrentOpenFilePath(saveDialog.FileName);
                //设置最近打开文件
                SetInitCurrentOpenFilePath();
            }

           
        }

        /// <summary>
        /// 关闭
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void menu_item_Close_Click(object sender, EventArgs e)
        {

        }
        #endregion

        #region 树处理
        /// <summary>
        /// Tree处理
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void treeTemplate_AfterSelect(object sender, TreeViewEventArgs e)
        {
            if (e != null)
            {
                _tnRightKey = e.Node;
                _tnLeftKey = e.Node;
            }
        }

        /// <summary>
        /// 鼠标按下
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void treeTemplate_MouseDown(object sender, MouseEventArgs e)
        {
            //右键菜单
            if (e.Button == MouseButtons.Right)
            {
                TreeNode tn = treeTemplate.GetNodeAt(e.X, e.Y);
                if (tn != null)
                {
                    treeTemplate.SelectedNode = tn;
                    //存储当前节点状态
                    _tnRightKey = tn;
                    treeTemplate.ContextMenuStrip = this.menuTreeNode;
                }
            }

            //左键生成代码
            if (e.Button == MouseButtons.Left)
            {
                TreeNode tn = treeTemplate.GetNodeAt(e.X, e.Y);

                if (tn != null && tn.Level > 1)
                {
                    _tnLeftKey = tn;
                    treeTemplate.SelectedNode = tn;

                    //切换到生成代码页面
                    this.tabControlMain.SelectedIndex = 1;

                    //调用引擎解析生成代码
                    AnalysisSvr _svr = new AnalysisSvr(_tnLeftKey.Text);
                    this.bRichTextBox1.Text = _svr.GetTemplateText(GetDBInfoList(),GetProjectInfo());
                }
            }


        }
        #endregion

        #region 当前状态变为保存
        private void chkRec_CheckedChanged(object sender, EventArgs e)
        {
            _CurrentState = (int)ECurrentSate.保存;
        }

        private void txtClassName_TextChanged(object sender, EventArgs e)
        {
            _CurrentState = (int)ECurrentSate.保存;
        }

        private void txtBaseClass_TextChanged(object sender, EventArgs e)
        {
            _CurrentState = (int)ECurrentSate.保存;
        }

        private void txtChildDataType_TextChanged(object sender, EventArgs e)
        {
            _CurrentState = (int)ECurrentSate.保存;
        }

        private void txtType_TextChanged(object sender, EventArgs e)
        {
            _CurrentState = (int)ECurrentSate.保存;
        }

        private void txtTabChildType_TextChanged(object sender, EventArgs e)
        {
            _CurrentState = (int)ECurrentSate.保存;
        }

        private void txtName_TextChanged(object sender, EventArgs e)
        {
            _CurrentState = (int)ECurrentSate.保存;
        }

        private void txtShowName_TextChanged(object sender, EventArgs e)
        {
            _CurrentState = (int)ECurrentSate.保存;
        }

        private void txtDataTableName_TextChanged(object sender, EventArgs e)
        {
            _CurrentState = (int)ECurrentSate.保存;
        }

        private void txtNameSpace_TextChanged(object sender, EventArgs e)
        {
            _CurrentState = (int)ECurrentSate.保存;
        }

        private void txtAssembly_TextChanged(object sender, EventArgs e)
        {
            _CurrentState = (int)ECurrentSate.保存;
        }
        private void txtExtention1_TextChanged(object sender, EventArgs e)
        {
            _CurrentState = (int)ECurrentSate.保存;
        }

        private void txtExtention2_TextChanged(object sender, EventArgs e)
        {
            _CurrentState = (int)ECurrentSate.保存;
        }

        private void txtExtention3_TextChanged(object sender, EventArgs e)
        {
            _CurrentState = (int)ECurrentSate.保存;
        }


        #endregion 重要方法


        
        #region 文本处理
        /// <summary>
        /// 清空左边对象
        /// </summary>
        private void ClearProjectInfo()
        {
            chkRec.Checked = false;
            txtAssembly.Clear();
            cmbBaseClass.SelectedItem = "";
            txtChildDataType.Clear();
            txtClassName.Clear();
            txtDataTableName.Clear();
            txtName.Clear();
            txtNameSpace.Clear();
            txtShowName.Clear();
            txtTabChildType.Clear();
            //txtExtention1.Clear();
            //txtExtention2.Clear();
            //txtExtention1.Clear();
            txtType.Clear();
            
        }
        #endregion

        #region 模型生成方法 私有

        /// <summary>
        /// 获取模型文本
        /// </summary>
        /// <returns></returns>
        private string GetModelText()
        {
            string str = string.Empty;

            //ProjcetInfo的Xml文档内容
            str += GetProjectInfoXmlText();

            //添加自己定义的分隔符
            str += "|**|";

            //DBInfoList的Xml文档内容
            str += GetucDBDesignXmlText();
            return str;
        }

        /// <summary>
        /// 获取右边数据库设计的序列化值
        /// </summary>
        private string GetucDBDesignXmlText()
        {
            ArrayList collection= ucDBDesign1.GetTemplateXml;
            if (collection.Count == 0)
                return "";
            //组件对象集合
            int iout = 0;
            bool bout = false;

            DBInfoList _list = new DBInfoList();

            for(int i=0;i<collection.Count;i++)
            {
                DataGridViewRow row = collection[i] as DataGridViewRow;

                DBInfo info = new DBInfo();
                if (row.Cells[0].Value != null)
                    info.ID = row.Cells[0].Value.ToString(); ;      // ID
                if (row.Cells[1].Value != null)
                    info.DisplayName = row.Cells[1].Value.ToString();      // 显示名称
                if(row.Cells[2].Value!=null)
                    info.Param = row.Cells[2].Value.ToString();      // 参数
                info.DataType = row.Cells[3].Value.ToString();      // 数据类型

                if (row.Cells[4].Value!=null)
                    info.XmlNode = bool.Parse(row.Cells[4].Value.ToString());      // 作为Xml节点，不选默认生成节点，同时选择默认为节点
                else
                    info.XmlNode = false;

                if (row.Cells[5].Value != null)
                    info.XmlAttribute = bool.Parse(row.Cells[5].Value.ToString());       // 作为Xml属性，不选默认生成节点，同时选择默认为节点
                else
                    info.XmlAttribute = false;


                if (row.Cells[6].Value != null&&Int32.TryParse(row.Cells[6].Value.ToString(), out iout))
                    info.Width = Int32.Parse(row.Cells[6].Value.ToString());       // 宽度
                else
                    info.Width = 0;

                if (row.Cells[7].Value != null && Int32.TryParse(row.Cells[7].Value.ToString(), out iout))
                    info.FloatLength = Int32.Parse(row.Cells[7].Value.ToString());      // 小数长度
                else
                    info.FloatLength = 0;

                if (row.Cells[8].Value != null)
                    info.PrimeKey = bool.Parse(row.Cells[8].Value.ToString());      // 主键，最多一个，多选了则默认需要的第一个
                else
                    info.PrimeKey = false;

                if (row.Cells[9].Value != null)
                    info.IsNotNull = bool.Parse(row.Cells[9].Value.ToString());       // 是否为空，不选则可以为空
                else
                    info.IsNotNull = false;

                if (row.Cells[10].Value != null)
                    info.IsQuery = bool.Parse(row.Cells[10].Value.ToString());      // 是否做为查询字段
                else
                    info.IsQuery = false;

                if (row.Cells[11].Value != null)
                    info.IsOrderBy = bool.Parse(row.Cells[11].Value.ToString());       // 是否作为排序字段
                else
                    info.IsOrderBy = false;

                if (row.Cells[12].Value != null)
                    info.IsIndex = bool.Parse(row.Cells[12].Value.ToString());       // 是否索引
                else
                    info.IsIndex = false;

                if (info != null)
                    _list.Add(info);
            }

            return _list.XMLText;
        }

        /// <summary>
        /// 获取左边ProjectInfo序列化值
        /// </summary>
        private string GetProjectInfoXmlText()
        {
            ProjectInfo info = new ProjectInfo();
            info.Rec=chkRec.Checked;      // 是否加Rec后缀
            info.ClassName = txtClassName.Text.Trim();      // 类名

             info.BaseClass=cmbBaseClass.Text.Trim();      // 基类名
             info.ChildDataType = txtChildDataType.Text.Trim();      // 子数据类型
             info.DataType = txtType.Text.Trim();      // 类型
             info.TableChildType = txtTabChildType.Text.Trim();      // 表格子类型
             info.Name = txtName.Text.Trim();      // 名称
             info.DisplayName = txtShowName.Text.Trim();      // 显示名称
             info.DataTableName = txtDataTableName.Text.Trim();      // 数据表名称
             info.Namespace = txtNameSpace.Text.Trim();      // 命名空间
             info.Asemmbly = txtAssembly.Text.Trim();      // 装配集
             //info.Extention1 = txtExtention1.Text.Trim();
             //info.Extention2 = txtExtention2.Text.Trim();
             //info.Extention3 = txtExtention3.Text.Trim();

            return info.XMLText;

        }

        /// <summary>
        /// 构建Model的根节点
        /// </summary>
        /// <returns></returns>
        private string BuildModelRootNodeBegin()
        {
            return "<?xml version=\"1.0\" encoding=\"utf-8\" ?><BMDRoot Version=\"1.0\">";
        
        }
        /// <summary>
        /// 构建Model的根节点
        /// </summary>
        /// <returns></returns>
        private string BuildModelRootNodeEnd()
        {
            return @"</BMDRoot>";
        
        }

        /// <summary>
        /// 加载模型文件
        /// </summary>
        /// <param name="p"></param>
        private void LoadModel(string filepath)
        {
            string strtext= FileOperSvr.IOAccess.GetWordText(filepath);
            if (string.IsNullOrEmpty(strtext))
                throw new Exception("模型错误");

            string[] strp={"|**|"};
            string[] strmodel = strtext.Split(strp,StringSplitOptions.None);
            if(strmodel.Length!=2)
                throw new Exception("模型错误");

            ProjectInfo item = new ProjectInfo();
            item.XMLText = strmodel[0];

            DBInfoList itemList = new DBInfoList();
            itemList.XMLText = strmodel[1];

            LoadProjectInfo(item);
            LoadDBInfo(itemList);
        }

        private void LoadProjectInfo(ProjectInfo item)
        {
            chkRec.Checked = item.Rec;
            txtAssembly.Text = item.Asemmbly;
            cmbBaseClass.SelectedItem= item.BaseClass;
            txtChildDataType.Text = item.ChildDataType;
            txtClassName.Text = item.ClassName;
            txtDataTableName.Text = item.DataTableName;
            txtName.Text = item.Name;
            txtNameSpace.Text = item.Namespace;
            txtShowName.Text = item.DisplayName;
            txtTabChildType.Text = item.TableChildType;
            txtType.Text = item.DataType;
            //txtExtention1.Text = item.Extention1;
            //txtExtention2.Text = item.Extention2;
            //txtExtention3.Text = item.Extention3;
        }

        private void LoadDBInfo(DBInfoList itemList)
        {
            for(int i=0;i<itemList.Count;i++)
            {
                DBInfo item=itemList[i] as DBInfo;



                ucDBDesign1.DBInfoDataGridView.Rows[i].Cells[0].Value = item.ID;   // ID
                ucDBDesign1.DBInfoDataGridView.Rows[i].Cells[1].Value = item.DisplayName;     // 显示名称
                ucDBDesign1.DBInfoDataGridView.Rows[i].Cells[2].Value = item.Param;      // 参数
                ucDBDesign1.DBInfoDataGridView.Rows[i].Cells[3].Value = item.DataType;     // 数据类型

                if (item.XmlNode == true)
                    ucDBDesign1.DBInfoDataGridView.Rows[i].Cells[4].Value = "True";
                else
                    ucDBDesign1.DBInfoDataGridView.Rows[i].Cells[4].Value = "False";

                if (item.XmlAttribute == true)
                    ucDBDesign1.DBInfoDataGridView.Rows[i].Cells[5].Value = "True";
                else
                    ucDBDesign1.DBInfoDataGridView.Rows[i].Cells[5].Value = "False";


                ucDBDesign1.DBInfoDataGridView.Rows[i].Cells[6].Value = item.Width.ToString();

                ucDBDesign1.DBInfoDataGridView.Rows[i].Cells[7].Value = item.FloatLength.ToString();

                if (item.PrimeKey == true)
                    ucDBDesign1.DBInfoDataGridView.Rows[i].Cells[8].Value = "True";
                else
                    ucDBDesign1.DBInfoDataGridView.Rows[i].Cells[8].Value = "False";

                if (item.IsNotNull == true)
                    ucDBDesign1.DBInfoDataGridView.Rows[i].Cells[9].Value = "True";
                else
                    ucDBDesign1.DBInfoDataGridView.Rows[i].Cells[9].Value = "False";

                if (item.IsQuery == true)
                    ucDBDesign1.DBInfoDataGridView.Rows[i].Cells[10].Value = "True";
                else
                    ucDBDesign1.DBInfoDataGridView.Rows[i].Cells[10].Value = "False";

                if (item.IsOrderBy == true)
                    ucDBDesign1.DBInfoDataGridView.Rows[i].Cells[11].Value = "True";
                else
                    ucDBDesign1.DBInfoDataGridView.Rows[i].Cells[11].Value = "False";

                if (item.IsIndex == true)
                    ucDBDesign1.DBInfoDataGridView.Rows[i].Cells[12].Value = "True";
                else
                    ucDBDesign1.DBInfoDataGridView.Rows[i].Cells[12].Value = "False";
            }
        }


        /// <summary>
        /// 获取DBInfoList对象
        /// </summary>
        /// <returns></returns>
        public DBInfoList GetDBInfoList()
        {
            DBInfoList list = new DBInfoList();
            list.XMLText = GetucDBDesignXmlText();
            return list;
        }

        /// <summary>
        /// 获取ProjectInfo对象
        /// </summary>
        /// <returns></returns>
        public ProjectInfo GetProjectInfo()
        {
            ProjectInfo item = new ProjectInfo();
            item.XMLText=GetProjectInfoXmlText();
            return item;
        }


        #endregion

        #region 生成文件的方法

        private void BulidFile()
        {
            TreeAttribute attribute = _tnRightKey.Tag as TreeAttribute;

            string filepath = string.Empty;

            FolderBrowserDialog dialog = new FolderBrowserDialog();
            dialog.ShowNewFolderButton = true;
            AnalysisSvr _svr = new AnalysisSvr(_tnRightKey.Text);

            if (attribute.Text.Contains("Domain"))
            {
                if (dialog.ShowDialog() == DialogResult.OK)
                {
                    filepath = dialog.SelectedPath;
                    bRichTextBox1.Text = _svr.GetTemplateText(GetDBInfoList(), GetProjectInfo());
                    bRichTextBox1.SaveFile(filepath + @"\" + GetProjectInfo().ClassName + ".cs", RichTextBoxStreamType.PlainText);
                    bRichTextBox1.SaveFile(filepath + @"\" + GetProjectInfo().ClassName + ".cs", RichTextBoxStreamType.PlainText);
                }
                return;
            }
            if (attribute.Text.Contains("Dao"))
            {
                if (dialog.ShowDialog() == DialogResult.OK)
                {
                    filepath = dialog.SelectedPath;
                    bRichTextBox1.Text = _svr.GetTemplateText(GetDBInfoList(), GetProjectInfo());
                    bRichTextBox1.SaveFile(filepath + @"\" + GetProjectInfo().ClassName + "Dao.cs", RichTextBoxStreamType.PlainText);
                    bRichTextBox1.SaveFile(filepath + @"\" + GetProjectInfo().ClassName + "Dao.cs", RichTextBoxStreamType.PlainText);
                }
                return;
            }
            if (attribute.Text.Contains("Server") && !attribute.Text.Contains("ServerEx"))
            {
                if (dialog.ShowDialog() == DialogResult.OK)
                {
                    filepath = dialog.SelectedPath;
                    bRichTextBox1.Text = _svr.GetTemplateText(GetDBInfoList(), GetProjectInfo());
                    bRichTextBox1.SaveFile(filepath + @"\" + GetProjectInfo().ClassName + "Svr.cs", RichTextBoxStreamType.PlainText);
                    bRichTextBox1.SaveFile(filepath + @"\" + GetProjectInfo().ClassName + "Svr.cs", RichTextBoxStreamType.PlainText);
                }
                return;
            }
            if (attribute.Text.Contains("ServerEx"))
            {
                if (dialog.ShowDialog() == DialogResult.OK)
                {
                    filepath = dialog.SelectedPath;
                    bRichTextBox1.Text = _svr.GetTemplateText(GetDBInfoList(), GetProjectInfo());
                    bRichTextBox1.SaveFile(filepath + @"\" + GetProjectInfo().ClassName + "SvrEx.cs", RichTextBoxStreamType.PlainText);
                    bRichTextBox1.SaveFile(filepath + @"\" + GetProjectInfo().ClassName + "SvrEx.cs", RichTextBoxStreamType.PlainText);
                }
                return;
            }
            if (attribute.Text.Contains("SQLMap"))
            {
                if (dialog.ShowDialog() == DialogResult.OK)
                {
                    filepath = dialog.SelectedPath;
                    bRichTextBox1.Text = _svr.GetTemplateText(GetDBInfoList(), GetProjectInfo());
                    bRichTextBox1.SaveFile(filepath + @"\" + GetProjectInfo().ClassName + ".xml", RichTextBoxStreamType.PlainText);
                    bRichTextBox1.SaveFile(filepath + @"\" + GetProjectInfo().ClassName + ".xml", RichTextBoxStreamType.PlainText);
                }
                return;
            }
            if (attribute.Text.Contains("SQLTable"))
            {
                if (dialog.ShowDialog() == DialogResult.OK)
                {
                    filepath = dialog.SelectedPath;
                    bRichTextBox1.Text = _svr.GetTemplateText(GetDBInfoList(), GetProjectInfo());
                    bRichTextBox1.SaveFile(filepath + @"\" + GetProjectInfo().ClassName + ".sql", RichTextBoxStreamType.PlainText);
                    bRichTextBox1.SaveFile(filepath + @"\" + GetProjectInfo().ClassName + ".sql", RichTextBoxStreamType.PlainText);
                }
                return;
            }

            MessageBox.Show("你所选择的节点无法生成代码！","提示");
        }

        /// <summary>
        /// 生成全部文件
        /// </summary>
        private void BulidFileEx()
        {
            string filepath = string.Empty;

            FolderBrowserDialog dialog = new FolderBrowserDialog();
            dialog.ShowNewFolderButton = true;

            if (dialog.ShowDialog() == DialogResult.OK)
            {
                foreach (TreeNode node in treeTemplate.Nodes[0].FirstNode.Nodes)
                {
                    if (node.Level == 2)
                    {
                        AnalysisSvr _svr = new AnalysisSvr(node.Text);


                        filepath = dialog.SelectedPath;
                        bRichTextBox1.Text = _svr.GetTemplateText(GetDBInfoList(), GetProjectInfo());

                        if (node.Text.Contains("Domain"))
                        {
                            bRichTextBox1.SaveFile(filepath + @"\" + GetProjectInfo().ClassName + ".cs", RichTextBoxStreamType.PlainText);
                            bRichTextBox1.SaveFile(filepath + @"\" + GetProjectInfo().ClassName + ".cs", RichTextBoxStreamType.PlainText);
                        }
                        if (node.Text.Contains("Dao"))
                        {
                            bRichTextBox1.SaveFile(filepath + @"\" + GetProjectInfo().ClassName + "Dao.cs", RichTextBoxStreamType.PlainText);
                            bRichTextBox1.SaveFile(filepath + @"\" + GetProjectInfo().ClassName + "Dao.cs", RichTextBoxStreamType.PlainText);
                        }
                        if (node.Text.Contains("Server") && !node.Text.Contains("ServerEx"))
                        {
                            bRichTextBox1.SaveFile(filepath + @"\" + GetProjectInfo().ClassName + "Svr.cs", RichTextBoxStreamType.PlainText);
                            bRichTextBox1.SaveFile(filepath + @"\" + GetProjectInfo().ClassName + "Svr.cs", RichTextBoxStreamType.PlainText);
                        }
                        if (node.Text.Contains("ServerEx"))
                        {
                            bRichTextBox1.SaveFile(filepath + @"\" + GetProjectInfo().ClassName + "SvrEx.cs", RichTextBoxStreamType.PlainText);
                            bRichTextBox1.SaveFile(filepath + @"\" + GetProjectInfo().ClassName + "SvrEx.cs", RichTextBoxStreamType.PlainText);
                        }
                        if (node.Text.Contains("SQLMap"))
                        {
                            bRichTextBox1.SaveFile(filepath + @"\" + GetProjectInfo().ClassName + ".xml", RichTextBoxStreamType.PlainText);
                            bRichTextBox1.SaveFile(filepath + @"\" + GetProjectInfo().ClassName + ".xml", RichTextBoxStreamType.PlainText);
                        }
                        if (node.Text.Contains("SQLTable"))
                        {
                            bRichTextBox1.SaveFile(filepath + @"\" + GetProjectInfo().ClassName + ".sql", RichTextBoxStreamType.PlainText);
                            bRichTextBox1.SaveFile(filepath + @"\" + GetProjectInfo().ClassName + ".sql", RichTextBoxStreamType.PlainText);
                        }

                    }
                }
            }
        }

        #endregion

        /// <summary>
        /// 设置最近打开文件路径
        /// </summary>
        private void SetInitCurrentOpenFilePath()
        {
            if (!string.IsNullOrEmpty(CommentConfig.GetConfig("CurrentOpen1")))
            {
                menu_item_Curr1.Visible = true;
                menu_item_Curr1.Text = CommentConfig.GetConfig("CurrentOpen1");
            }
            else
                menu_item_Curr1.Visible = false;

            if (!string.IsNullOrEmpty(CommentConfig.GetConfig("CurrentOpen2")))
            {
                menu_item_Curr2.Visible = true;
                menu_item_Curr2.Text = CommentConfig.GetConfig("CurrentOpen2");
            }
            else
                menu_item_Curr2.Visible = false;

            if (!string.IsNullOrEmpty(CommentConfig.GetConfig("CurrentOpen3")))
            {
                menu_item_Curr3.Visible = true;
                menu_item_Curr3.Text = CommentConfig.GetConfig("CurrentOpen3");
            }
            else
                menu_item_Curr3.Visible = false;

            if (!string.IsNullOrEmpty(CommentConfig.GetConfig("CurrentOpen4")))
            {
                menu_item_Curr4.Visible = true;
                menu_item_Curr4.Text = CommentConfig.GetConfig("CurrentOpen4");
            }
            else
                menu_item_Curr4.Visible = false;

            if (!string.IsNullOrEmpty(CommentConfig.GetConfig("CurrentOpen5")))
            {
                menu_item_Curr5.Visible = true;
                menu_item_Curr5.Text = CommentConfig.GetConfig("CurrentOpen5");
            }
            else
                menu_item_Curr5.Visible = false;
        }

        /// <summary>
        /// 更新最新打开文件路径
        /// </summary>
        /// <param name="newPath"></param>
        private void SetCurrentOpenFilePath(string newPath)
        {
            XmlDocument xmlDoc = new XmlDocument();
            string path = "Config.xml";
             xmlDoc.Load(path);
            XmlNodeList nodeList = xmlDoc.SelectSingleNode("Root").ChildNodes;//获取bookstore节点的所有子节点

            string strlastname = string.Empty;
            foreach (XmlNode xn in nodeList)//遍历所有子节点 
            {
                if(xn.Name=="CurrentOpen4")
                    strlastname=xn.InnerText;

                if (xn.Name == "CurrentOpen5")
                {
                    xn.InnerText = strlastname;

                    FileInfo fi = new FileInfo(path);
                    if (fi.Attributes.ToString().IndexOf("ReadOnly") != -1)
                    {
                        fi.Attributes = FileAttributes.Normal;
                    }
                    xmlDoc.Save(path);

                }
            }

            string strlastname2 = string.Empty;
            foreach (XmlNode xn in nodeList)//遍历所有子节点 
            {
                if (xn.Name == "CurrentOpen3")
                    strlastname2 = xn.InnerText;

                if (xn.Name == "CurrentOpen4")
                {
                    xn.InnerText = strlastname2;

                    FileInfo fi = new FileInfo(path);
                    if (fi.Attributes.ToString().IndexOf("ReadOnly") != -1)
                    {
                        fi.Attributes = FileAttributes.Normal;
                    }
                    xmlDoc.Save(path);
                }
            }

            string strlastname3 = string.Empty;
            foreach (XmlNode xn in nodeList)//遍历所有子节点 
            {
                if (xn.Name == "CurrentOpen2")
                    strlastname3 = xn.InnerText;

                if (xn.Name == "CurrentOpen3")
                {
                    xn.InnerText = strlastname3;

                    FileInfo fi = new FileInfo(path);
                    if (fi.Attributes.ToString().IndexOf("ReadOnly") != -1)
                    {
                        fi.Attributes = FileAttributes.Normal;
                    }
                    xmlDoc.Save(path);
                }
            }

            string strlastname4 = string.Empty;
            foreach (XmlNode xn in nodeList)//遍历所有子节点 
            {
                if (xn.Name == "CurrentOpen1")
                    strlastname4 = xn.InnerText;

                if (xn.Name == "CurrentOpen2")
                {
                    xn.InnerText = strlastname4;

                    FileInfo fi = new FileInfo(path);
                    if (fi.Attributes.ToString().IndexOf("ReadOnly") != -1)
                    {
                        fi.Attributes = FileAttributes.Normal;
                    }
                    xmlDoc.Save(path);
                }
            }

            foreach (XmlNode xn in nodeList)//遍历所有子节点 
            {
                if (xn.Name == "CurrentOpen1")
                {
                    xn.InnerText = newPath;

                    FileInfo fi = new FileInfo(path);
                    if (fi.Attributes.ToString().IndexOf("ReadOnly") != -1)
                    {
                        fi.Attributes = FileAttributes.Normal;
                    }
                    xmlDoc.Save(path);
                }
            }
        }

        /// <summary>
        /// 获取上次更新路径
        /// </summary>
        /// <param name="newPath"></param>
        private string GetLastOpenPath()
        {
            XmlDocument xmlDoc = new XmlDocument();
            string path = "Config.xml";
            xmlDoc.Load(path);
            XmlNodeList nodeList = xmlDoc.SelectSingleNode("Root").ChildNodes;//获取bookstore节点的所有子节点

            foreach (XmlNode xn in nodeList)//遍历所有子节点 
            {

                if (xn.Name == "LastOpenPath")
                {
                    return xn.InnerText;

                }
            }

            return null;
        }

        /// <summary>
        /// 设置上次更新路径
        /// </summary>
        /// <param name="newPath"></param>
        private void SetLastOpenPath(string newPath)
        {
            XmlDocument xmlDoc = new XmlDocument();
            string path = "Config.xml";
            xmlDoc.Load(path);
            XmlNodeList nodeList = xmlDoc.SelectSingleNode("Root").ChildNodes;//获取bookstore节点的所有子节点

            foreach (XmlNode xn in nodeList)//遍历所有子节点 
            {

                if (xn.Name == "LastOpenPath")
                {
                    xn.InnerText = newPath;

                    FileInfo fi = new FileInfo(path);
                    if (fi.Attributes.ToString().IndexOf("ReadOnly") != -1)
                    {
                        fi.Attributes = FileAttributes.Normal;
                    }
                    xmlDoc.Save(path);

                }
            }
        }

        private void OpenCurrentFile(string strpath)
        {
            if (_CurrentState == (int)ECurrentSate.保存)
            {
                DialogResult result = MessageBox.Show("在打开文件前将保存对当前文件的保存，你确定吗", "文件保存提示", MessageBoxButtons.YesNoCancel, MessageBoxIcon.Information);

                if (result == DialogResult.Yes)
                {
                    SaveFileDialog saveDialog = new SaveFileDialog();
                    //初始化路径,可通过XML扩展

                    string openpath = GetLastOpenPath();

                    if (!string.IsNullOrEmpty(openpath))
                        saveDialog.InitialDirectory = GetLastOpenPath(); //Application.StartupPath;
                    else
                        saveDialog.InitialDirectory = Application.StartupPath;


                    saveDialog.Title = "请选择模型文件的位置";
                    //文件类型，可通过XML扩展
                    saveDialog.Filter = "BLModel(*.blm)|*.blm";
                    saveDialog.RestoreDirectory = true;
                    saveDialog.FilterIndex = 0;

                    if (saveDialog.ShowDialog() == DialogResult.OK)
                    {
                        FileOperSvr.IOAccess.WriteFile(saveDialog.FileName, GetModelText());
                        SetLastOpenPath(saveDialog.FileName);
                    }


                }
            }

            //加载模型
            try
            {
                LoadModel(strpath);
            }
            catch (Exception err)
            {
                MessageBox.Show("你加载的模型有错，请检查！\n以下是系统返回的信息" + err.ToString());
            }

            //存储路径
            _CurrentFilePath = strpath;
            this.Text = _CurrentFilePath;

            SetInitCurrentOpenFilePath();
        }
       


    }
}