﻿using System;
using System.Collections;
using System.Text;
using PengeSoft.Data;
using PengeSoft.WorkZoneData;

namespace TEngine
{
    /// <summary>
    /// DBInfo 数据库设计的摘要说明。
    /// </summary>
    public class DBInfo:DataPacket 
    {
        #region 私有字段
        
        private string   _ID           ;      // ID
        private string   _DisplayName  ;      // 显示名称
        private string   _Param        ;      // 参数
        private string   _DataType     ;      // 数据类型
        private bool     _XmlNode      ;      // 作为Xml节点，不选默认生成节点，同时选择默认为节点
        private bool     _XmlAttribute ;      // 作为Xml属性，不选默认生成节点，同时选择默认为节点
        private int      _Width        ;      // 宽度
        private int      _FloatLength  ;      // 小数长度
        private bool     _PrimeKey     ;      // 主键，最多一个，多选了则默认需要的第一个
        private bool     _IsNotNull    ;      // 是否为空，不选则可以为空
        private bool     _IsQuery      ;      // 是否做为查询字段
        private bool     _IsOrderBy    ;      // 是否作为排序字段
        private bool     _IsIndex      ;      // 是否索引

        #endregion

        #region 属性定义

        /// <summary>
        /// ID 
        /// </summary>
        public string   ID            { get { return _ID           ;} set { _ID            = value; } }
        /// <summary>
        /// 显示名称 
        /// </summary>
        public string   DisplayName   { get { return _DisplayName  ;} set { _DisplayName   = value; } }
        /// <summary>
        /// 参数 
        /// </summary>
        public string   Param         { get { return _Param        ;} set { _Param         = value; } }
        /// <summary>
        /// 数据类型 
        /// </summary>
        public string   DataType      { get { return _DataType     ;} set { _DataType      = value; } }
        /// <summary>
        /// 作为Xml节点，不选默认生成节点，同时选择默认为节点 
        /// </summary>
        public bool     XmlNode       { get { return _XmlNode      ;} set { _XmlNode       = value; } }
        /// <summary>
        /// 作为Xml属性，不选默认生成节点，同时选择默认为节点 
        /// </summary>
        public bool     XmlAttribute  { get { return _XmlAttribute ;} set { _XmlAttribute  = value; } }
        /// <summary>
        /// 宽度 
        /// </summary>
        public int      Width         { get { return _Width        ;} set { _Width         = value; } }
        /// <summary>
        /// 小数长度 
        /// </summary>
        public int      FloatLength   { get { return _FloatLength  ;} set { _FloatLength   = value; } }
        /// <summary>
        /// 主键，最多一个，多选了则默认需要的第一个 
        /// </summary>
        public bool     PrimeKey      { get { return _PrimeKey     ;} set { _PrimeKey      = value; } }
        /// <summary>
        /// 是否为空，不选则可以为空 
        /// </summary>
        public bool     IsNotNull     { get { return _IsNotNull    ;} set { _IsNotNull     = value; } }
        /// <summary>
        /// 是否做为查询字段 
        /// </summary>
        public bool     IsQuery       { get { return _IsQuery      ;} set { _IsQuery       = value; } }
        /// <summary>
        /// 是否作为排序字段 
        /// </summary>
        public bool     IsOrderBy     { get { return _IsOrderBy    ;} set { _IsOrderBy     = value; } }
        /// <summary>
        /// 是否索引 
        /// </summary>
        public bool     IsIndex       { get { return _IsIndex      ;} set { _IsIndex       = value; } }

        #endregion

        #region 重载公共函数

        /// <summary>
        /// 清除所有数据。
        /// </summary>
        public override void Clear()
        {
            base.Clear ();

            _ID            = null;
            _DisplayName   = null;
            _Param         = null;
            _DataType      = null;
            _XmlNode       = false;
            _XmlAttribute  = false;
            _Width         = 0;
            _FloatLength   = 0;
            _PrimeKey      = false;
            _IsNotNull     = false;
            _IsQuery       = false;
            _IsOrderBy     = false;
            _IsIndex       = false;
        }

        /// <summary>
        /// 用指定节点序列化整个数据对象。
        /// </summary>
        /// <param name="node">用于序列化的 XmlNode 节点。</param>
        public override void XMLEncode(System.Xml.XmlNode node)
        {
            base.XMLEncode (node);

            WriteXmlAttrValue(node, "ID", _ID);
            WriteXmlAttrValue(node, "DisplayName", _DisplayName);
            WriteXmlAttrValue(node, "Param", _Param);
            WriteXmlAttrValue(node, "DataType", _DataType);
            WriteXmlAttrValue(node, "XmlNode", _XmlNode);
            WriteXmlAttrValue(node, "XmlAttribute", _XmlAttribute);
            WriteXmlAttrValue(node, "Width", _Width);
            WriteXmlAttrValue(node, "FloatLength", _FloatLength);
            WriteXmlAttrValue(node, "PrimeKey", _PrimeKey);
            WriteXmlAttrValue(node, "IsNotNull", _IsNotNull);
            WriteXmlAttrValue(node, "IsQuery", _IsQuery);
            WriteXmlAttrValue(node, "IsOrderBy", _IsOrderBy);
            WriteXmlAttrValue(node, "IsIndex", _IsIndex);
        }

        /// <summary>
        /// 用指定节点反序列化整个数据对象。
        /// </summary>
        /// <param name="node">用于反序列化的 XmlNode 节点。</param>
        public override void XMLDecode(System.Xml.XmlNode node)
        {
            base.XMLDecode (node);

            ReadXmlAttrValue(node, "ID", ref _ID);
            ReadXmlAttrValue(node, "DisplayName", ref _DisplayName);
            ReadXmlAttrValue(node, "Param", ref _Param);
            ReadXmlAttrValue(node, "DataType", ref _DataType);
            ReadXmlAttrValue(node, "XmlNode", ref _XmlNode);
            ReadXmlAttrValue(node, "XmlAttribute", ref _XmlAttribute);
            ReadXmlAttrValue(node, "Width", ref _Width);
            ReadXmlAttrValue(node, "FloatLength", ref _FloatLength);
            ReadXmlAttrValue(node, "PrimeKey", ref _PrimeKey);
            ReadXmlAttrValue(node, "IsNotNull", ref _IsNotNull);
            ReadXmlAttrValue(node, "IsQuery", ref _IsQuery);
            ReadXmlAttrValue(node, "IsOrderBy", ref _IsOrderBy);
            ReadXmlAttrValue(node, "IsIndex", ref _IsIndex);
        }

        /// <summary>
        /// 复制数据对象
        /// </summary>
        /// <param name="sou">源对象,需从DataPacket继承</param>
        public override void AssignFrom(DataPacket sou)
        {
            base.AssignFrom (sou);

            DBInfo s = sou as DBInfo;
            if (s != null)
            {
                _ID            = s._ID           ;
                _DisplayName   = s._DisplayName  ;
                _Param         = s._Param        ;
                _DataType      = s._DataType     ;
                _XmlNode       = s._XmlNode      ;
                _XmlAttribute  = s._XmlAttribute ;
                _Width         = s._Width        ;
                _FloatLength   = s._FloatLength  ;
                _PrimeKey      = s._PrimeKey     ;
                _IsNotNull     = s._IsNotNull    ;
                _IsQuery       = s._IsQuery      ;
                _IsOrderBy     = s._IsOrderBy    ;
                _IsIndex       = s._IsIndex      ;
            }
        }

        #endregion
    }
}
