﻿using System;
using System.Collections;
using System.Text;
using PengeSoft.Data;
using PengeSoft.WorkZoneData;

namespace TEngine
{
    /// <summary>
    /// ProjectInfo 的摘要说明。
    /// </summary>
    public class ProjectInfo : DataPacket
    {
        #region 私有字段

        private bool _Rec;      // 是否加Rec后缀
        private string _ClassName;      // 类名
        private string _BaseClass;      // 基类名
        private string _ChildDataType;      // 子数据类型
        private string _DataType;      // 类型
        private string _TableChildType;      // 表格子类型
        private string _Name;      // 名称
        private string _DisplayName;      // 显示名称
        private string _DataTableName;      // 数据表名称
        private string _Namespace;      // 命名空间
        private string _Asemmbly;      // 装配集

        #endregion

        #region 属性定义

        /// <summary>
        /// 是否加Rec后缀 
        /// </summary>
        public bool Rec { get { return _Rec; } set { _Rec = value; } }
        /// <summary>
        /// 类名 
        /// </summary>
        public string ClassName { get { return _ClassName; } set { _ClassName = value; } }
        /// <summary>
        /// 基类名 
        /// </summary>
        public string BaseClass { get { return _BaseClass; } set { _BaseClass = value; } }
        /// <summary>
        /// 子数据类型 
        /// </summary>
        public string ChildDataType { get { return _ChildDataType; } set { _ChildDataType = value; } }
        /// <summary>
        /// 类型 
        /// </summary>
        public string DataType { get { return _DataType; } set { _DataType = value; } }
        /// <summary>
        /// 表格子类型 
        /// </summary>
        public string TableChildType { get { return _TableChildType; } set { _TableChildType = value; } }
        /// <summary>
        /// 名称 
        /// </summary>
        public string Name { get { return _Name; } set { _Name = value; } }
        /// <summary>
        /// 显示名称 
        /// </summary>
        public string DisplayName { get { return _DisplayName; } set { _DisplayName = value; } }
        /// <summary>
        /// 数据表名称 
        /// </summary>
        public string DataTableName { get { return _DataTableName; } set { _DataTableName = value; } }
        /// <summary>
        /// 命名空间 
        /// </summary>
        public string Namespace { get { return _Namespace; } set { _Namespace = value; } }
        /// <summary>
        /// 装配集 
        /// </summary>
        public string Asemmbly { get { return _Asemmbly; } set { _Asemmbly = value; } }

        #endregion

        #region 重载公共函数

        /// <summary>
        /// 清除所有数据。
        /// </summary>
        public override void Clear()
        {
            base.Clear();

            _Rec = false;
            _ClassName = null;
            _BaseClass = null;
            _ChildDataType = null;
            _DataType = null;
            _TableChildType = null;
            _Name = null;
            _DisplayName = null;
            _DataTableName = null;
            _Namespace = null;
            _Asemmbly = null;
        }

        /// <summary>
        /// 用指定节点序列化整个数据对象。
        /// </summary>
        /// <param name="node">用于序列化的 XmlNode 节点。</param>
        public override void XMLEncode(System.Xml.XmlNode node)
        {
            base.XMLEncode(node);

            WriteXmlAttrValue(node, "Rec", _Rec);
            WriteXmlAttrValue(node, "ClassName", _ClassName);
            WriteXmlAttrValue(node, "BaseClass", _BaseClass);
            WriteXmlAttrValue(node, "ChildDataType", _ChildDataType);
            WriteXmlAttrValue(node, "DataType", _DataType);
            WriteXmlAttrValue(node, "TableChildType", _TableChildType);
            WriteXmlAttrValue(node, "Name", _Name);
            WriteXmlAttrValue(node, "DisplayName", _DisplayName);
            WriteXmlAttrValue(node, "DataTableName", _DataTableName);
            WriteXmlAttrValue(node, "Namespace", _Namespace);
            WriteXmlAttrValue(node, "Asemmbly", _Asemmbly);
        }

        /// <summary>
        /// 用指定节点反序列化整个数据对象。
        /// </summary>
        /// <param name="node">用于反序列化的 XmlNode 节点。</param>
        public override void XMLDecode(System.Xml.XmlNode node)
        {
            base.XMLDecode(node);

            ReadXmlAttrValue(node, "Rec", ref _Rec);
            ReadXmlAttrValue(node, "ClassName", ref _ClassName);
            ReadXmlAttrValue(node, "BaseClass", ref _BaseClass);
            ReadXmlAttrValue(node, "ChildDataType", ref _ChildDataType);
            ReadXmlAttrValue(node, "DataType", ref _DataType);
            ReadXmlAttrValue(node, "TableChildType", ref _TableChildType);
            ReadXmlAttrValue(node, "Name", ref _Name);
            ReadXmlAttrValue(node, "DisplayName", ref _DisplayName);
            ReadXmlAttrValue(node, "DataTableName", ref _DataTableName);
            ReadXmlAttrValue(node, "Namespace", ref _Namespace);
            ReadXmlAttrValue(node, "Asemmbly", ref _Asemmbly);
        }

        /// <summary>
        /// 复制数据对象
        /// </summary>
        /// <param name="sou">源对象,需从DataPacket继承</param>
        public override void AssignFrom(DataPacket sou)
        {
            base.AssignFrom(sou);

            ProjectInfo s = sou as ProjectInfo;
            if (s != null)
            {
                _Rec = s._Rec;
                _ClassName = s._ClassName;
                _BaseClass = s._BaseClass;
                _ChildDataType = s._ChildDataType;
                _DataType = s._DataType;
                _TableChildType = s._TableChildType;
                _Name = s._Name;
                _DisplayName = s._DisplayName;
                _DataTableName = s._DataTableName;
                _Namespace = s._Namespace;
                _Asemmbly = s._Asemmbly;
            }
        }

        #endregion
    }
}
