﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Xml;
using System.Data;
using System.Windows.Forms;

namespace TreeMgeSvr
{
    public class XmlHelper
    {
         /// <summary>
        /// 获取xml文档根
        /// </summary>
        /// <param name="xmlpath">xml文件路径</param>
        /// <returns></returns>
        public static XmlNode GetXmlRoot(string xmlpath)
        {
            XmlDocument objXml = new XmlDocument();

            try
            {
                objXml.Load(xmlpath);
            }
            catch (Exception err)
            {
                MessageBox.Show("XML文件路径错误,或XML错误");
                return null;
            }

            return objXml.SelectSingleNode("BLRoot");

        }

        /// <summary>
        /// 返回xml文件的所有节点
        /// </summary>
        /// <param name="xmlpath">文件路径</param>
        /// <returns>xmlnodelist</returns>
        public static DataSet GetXmlDataSet(string xmlpath)
        {
            DataSet ds = new DataSet();
            ds.ReadXml(xmlpath);

            return ds;
        }

        /// <summary>
        /// 获取指定节点的内容
        /// </summary>
        /// <param name="filePath"></param>
        /// <param name="sXmlNode"></param>
        /// <returns></returns>
        public static string GetNodeValue(string sPath, string sXmlNode)
        {
            string sResult = string.Empty;
            //定义一个文档
            XmlDocument doc = new XmlDocument();
            //载入对象
            doc.Load(sPath);
            XmlNode node = doc.SelectSingleNode("//" + sXmlNode);
            if (node != null)
            {
                sResult = node.InnerText;
            }
            doc = null;
            return sResult;
        }

        /// <summary>
        /// 用结构体构建树节点
        /// </summary>
        /// <param name="attribute"></param>
        /// <returns></returns>
        public static void WriteNodeToTree(TreeAttribute attribute)
        {
            XmlDocument docWrite =new XmlDocument();
            try{
                docWrite.Load(Application.StartupPath + @"\Tree.xml");
            }
            catch
            {
                throw new Exception("Tree文件丢失");
            }
            XmlNode root = docWrite.SelectSingleNode("GARoot/" + attribute.Parent);
            XmlElement xe = docWrite.CreateElement(attribute.Name);

            xe.SetAttribute("Text", attribute.Text);
            xe.SetAttribute("Deep", attribute.Deep.ToString());
            xe.SetAttribute("Parent", attribute.Parent);
            xe.SetAttribute("Comment", attribute.Comment);
            xe.SetAttribute("Tag", attribute.Tag.ToString());

            root.AppendChild(xe);
            docWrite.Save(Application.StartupPath + @"\Tree.xml");

        }


        /// <summary>
        /// 编辑节点
        /// </summary>
        /// <param name="attribute"></param>
        public static void EditNodeToTree(TreeAttribute attribute)
        {
            XmlDocument docEdit = new XmlDocument();
            try
            {
                docEdit.Load(Application.StartupPath + @"\Tree.xml");
            }
            catch
            {
                throw new Exception("Tree文件丢失");
            }
            XmlElement xe = (XmlElement)docEdit.SelectSingleNode("BLRoot/" + attribute.Parent + "/" + attribute.Name);

            if (xe != null)
            {
                xe.SetAttribute("Text", attribute.Text);
                xe.SetAttribute("Deep", attribute.Deep.ToString());
                xe.SetAttribute("Parent", attribute.Parent);
                xe.SetAttribute("Comment", attribute.Comment);
                xe.SetAttribute("Tag", attribute.Tag.ToString());


            }
            docEdit.Save(Application.StartupPath + @"\Tree.xml");
           
        }

        public static bool DelNodeToTree(TreeAttribute attribute)
        { 
              XmlDocument docDel = new XmlDocument();
            try
            {
                docDel.Load(Application.StartupPath + @"\Tree.xml");
            }
            catch
            {
                throw new Exception("Tree文件丢失");
            }
            XmlNode xe = docDel.SelectSingleNode("GARoot/" + attribute.Parent + "/" + attribute.Name);

            if (xe == null)
                return false;
            
            xe.ParentNode.RemoveChild(xe);
            docDel.Save(Application.StartupPath + @"\Tree.xml");

            return true;
        }
    }
}
